@@ -38,7 +38,7 @@
 #define LBER_CALLOC(n,s)        calloc((n),(s))
 #define LBER_REALLOC(p,s)       realloc((p),(s))
 /*   vfree is defined in openldap-extract.h */
-#define LBER_VFREE(v)           vfree((void**)(v))
+#define LBER_VFREE(v)           vfree((gpointer *)(v))
 #define LBER_FREE(p)            free((p))
 #define LDAP_OPT_SSL 10
 #endif
@@ -61,7 +61,7 @@
 #define LDAP_CALLOC(n,s) calloc((n),(s))
 #define LDAP_REALLOC(p,s) realloc((p),(s))
 #define LDAP_FREE(p) free((p))
-#define LDAP_VFREE(p) vfree((void **)(p))
+#define LDAP_VFREE(p) vfree((gpointer *)(p))
 #define LDAP_STRDUP(s) strdup((s))
 
 #define LDAP_RANGE(n,x,y)	(((x) <= (n)) && ((n) <= (y)))
@@ -70,6 +70,19 @@
 #ifdef G_OS_WIN32
 #define ldap_msgtype(lm) (lm)->lm_msgtype
 #define ldap_msgid(lm) (lm)->lm_msgid
+#ifndef LDAP_TYPE_OR_VALUE_EXISTS
+#define LDAP_TYPE_OR_VALUE_EXISTS 0x14
+#endif
+#ifndef LDAP_SCOPE_DEFAULT
+#define LDAP_SCOPE_DEFAULT -1
+#endif
+#ifndef LDAP_OPT_SUCCESS
+#define LDAP_OPT_SUCCESS 0x00
+#endif
+#ifndef LDAP_INSUFFICIENT_ACCESS
+#define LDAP_INSUFFICIENT_ACCESS 0x32
+#endif
+
 #endif
 
 #define LDAP_SCHERR_OUTOFMEM		1
@@ -102,21 +115,20 @@
 #define	LDAP_SCHEMA_SKIP			0x80U /* Don't malloc any result      */
 
 typedef struct ldap_objectclass {
-	char *oc_oid;		/* REQUIRED */
-	char **oc_names;	/* OPTIONAL */
-	char *oc_desc;		/* OPTIONAL */
-	int  oc_obsolete;	/* 0=no, 1=yes */
-	char **oc_sup_oids;	/* OPTIONAL */
-	int  oc_kind;		/* 0=ABSTRACT, 1=STRUCTURAL, 2=AUXILIARY */
-	char **oc_at_oids_must;	/* OPTIONAL */
-	char **oc_at_oids_may;	/* OPTIONAL */
+	gchar *oc_oid;		/* REQUIRED */
+	gchar **oc_names;	/* OPTIONAL */
+	gchar *oc_desc;		/* OPTIONAL */
+	gint  oc_obsolete;	/* 0=no, 1=yes */
+	gchar **oc_sup_oids;	/* OPTIONAL */
+	gint  oc_kind;		/* 0=ABSTRACT, 1=STRUCTURAL, 2=AUXILIARY */
+	gchar **oc_at_oids_must;	/* OPTIONAL */
+	gchar **oc_at_oids_may;	/* OPTIONAL */
 } LDAPObjectClass;
 
-
 static void
-vfree(void **vec)
+vfree(gpointer *vec)
 {
-  int i;
+  gint i;
 
   for (i = 0; vec[i] != NULL; i++)
     free(vec[i]);
@@ -158,17 +170,17 @@ vfree(void **vec)
 #define TK_QDESCR	TK_QDSTRING
 
 struct token {
-	int type;
-	char *sval;
+	gint type;
+	gchar *sval;
 };
 
-static int
-get_token( const char ** sp, char ** token_val )
+static gint
+get_token( const gchar ** sp, gchar ** token_val )
 {
-	int kind;
-	const char * p;
-	const char * q;
-	char * res;
+	gint kind;
+	const gchar * p;
+	const gchar * q;
+	gchar * res;
 
 	*token_val = NULL;
 	switch (**sp) {
@@ -192,12 +204,12 @@ get_token( const char ** sp, char ** token_val )
 		kind = TK_QDSTRING;
 		(*sp)++;
 		p = *sp;
-		while ( **sp != '\'' && **sp != '\0' )
+		while (**sp != '\'' && **sp != '\0')
 			(*sp)++;
-		if ( **sp == '\'' ) {
+		if (**sp == '\'') {
 			q = *sp;
 			res = LDAP_MALLOC(q-p+1);
-			if ( !res ) {
+			if (!res) {
 				kind = TK_OUTOFMEM;
 			} else {
 				strncpy(res,p,q-p);
@@ -221,7 +233,7 @@ get_token( const char ** sp, char ** token_val )
 			(*sp)++;
 		q = *sp;
 		res = LDAP_MALLOC(q-p+1);
-		if ( !res ) {
+		if (!res) {
 			kind = TK_OUTOFMEM;
 		} else {
 			strncpy(res,p,q-p);
@@ -229,58 +241,58 @@ get_token( const char ** sp, char ** token_val )
 			*token_val = res;
 		}
 		break;
-/*  		kind = TK_UNEXPCHAR; */
-/*  		break; */
+/*		kind = TK_UNEXPCHAR; */
+/*		break; */
 	}
-	
+
 	return kind;
 }
 
 /* Gobble optional whitespace */
 static void
-parse_whsp(const char **sp)
+parse_whsp(const gchar **sp)
 {
 	while (LDAP_SPACE(**sp))
 		(*sp)++;
 }
 
 /* Parse a sequence of dot-separated decimal strings */
-static char *
-ldap_int_parse_numericoid(const char **sp, int *code, const int flags)
+static gchar *
+ldap_int_parse_numericoid(const gchar **sp, gint *code, const gint flags)
 {
-	char * res = NULL;
-	const char * start = *sp;
-	int len;
-	int quoted = 0;
+	gchar * res = NULL;
+	const gchar * start = *sp;
+	gint len;
+	gint quoted = 0;
 
 	/* Netscape puts the SYNTAX value in quotes (incorrectly) */
-	if ( flags & LDAP_SCHEMA_ALLOW_QUOTED && **sp == '\'' ) {
+	if (flags & LDAP_SCHEMA_ALLOW_QUOTED && **sp == '\'') {
 		quoted = 1;
 		(*sp)++;
 		start++;
 	}
 	/* Each iteration of this loop gets one decimal string */
 	while (**sp) {
-		if ( !LDAP_DIGIT(**sp) ) {
+		if (!LDAP_DIGIT(**sp)) {
 			/*
-			 * Initial char is not a digit or char after dot is
+			 * Initial gchar is not a digit or gchar after dot is
 			 * not a digit
 			 */
 			*code = LDAP_SCHERR_NODIGIT;
 			return NULL;
 		}
 		(*sp)++;
-		while ( LDAP_DIGIT(**sp) )
+		while (LDAP_DIGIT(**sp))
 			(*sp)++;
-		if ( **sp != '.' )
+		if (**sp != '.')
 			break;
 		/* Otherwise, gobble the dot and loop again */
 		(*sp)++;
 	}
-	/* Now *sp points at the char past the numericoid. Perfect. */
+	/* Now *sp points at the gchar past the numericoid. Perfect. */
 	len = *sp - start;
-	if ( flags & LDAP_SCHEMA_ALLOW_QUOTED && quoted ) {
-		if ( **sp == '\'' ) {
+	if (flags & LDAP_SCHEMA_ALLOW_QUOTED && quoted) {
+		if (**sp == '\'') {
 			(*sp)++;
 		} else {
 			*code = LDAP_SCHERR_UNEXPTOKEN;
@@ -288,7 +300,7 @@ ldap_int_parse_numericoid(const char **sp, int *code, const int flags)
 		}
 	}
 	if (flags & LDAP_SCHEMA_SKIP) {
-		res = (char *)start;
+		res = (gchar *)start;
 	} else {
 		res = LDAP_MALLOC(len+1);
 		if (!res) {
@@ -302,23 +314,23 @@ ldap_int_parse_numericoid(const char **sp, int *code, const int flags)
 }
 
 /* Parse a qdescr or a list of them enclosed in () */
-static char **
-parse_qdescrs(const char **sp, int *code)
+static gchar **
+parse_qdescrs(const gchar **sp, gint *code)
 {
-	char ** res;
-	char ** res1;
-	int kind;
-	char * sval;
-	int size;
-	int pos;
+	gchar ** res;
+	gchar ** res1;
+	gint kind;
+	gchar * sval;
+	gint size;
+	gint pos;
 
 	parse_whsp(sp);
 	kind = get_token(sp,&sval);
-	if ( kind == TK_LEFTPAREN ) {
+	if (kind == TK_LEFTPAREN) {
 		/* Let's presume there will be at least 2 entries */
 		size = 3;
-		res = LDAP_CALLOC(3,sizeof(char *));
-		if ( !res ) {
+		res = LDAP_CALLOC(3,sizeof(gchar *));
+		if (!res) {
 			*code = LDAP_SCHERR_OUTOFMEM;
 			return NULL;
 		}
@@ -326,13 +338,13 @@ parse_qdescrs(const char **sp, int *code)
 		while (1) {
 			parse_whsp(sp);
 			kind = get_token(sp,&sval);
-			if ( kind == TK_RIGHTPAREN )
+			if (kind == TK_RIGHTPAREN)
 				break;
-			if ( kind == TK_QDESCR ) {
-				if ( pos == size-2 ) {
+			if (kind == TK_QDESCR) {
+				if (pos == size-2) {
 					size++;
-					res1 = LDAP_REALLOC(res,size*sizeof(char *));
-					if ( !res1 ) {
+					res1 = LDAP_REALLOC(res,size*sizeof(gchar *));
+					if (!res1) {
 						LDAP_VFREE(res);
 						LDAP_FREE(sval);
 						*code = LDAP_SCHERR_OUTOFMEM;
@@ -352,9 +364,9 @@ parse_qdescrs(const char **sp, int *code)
 		}
 		parse_whsp(sp);
 		return(res);
-	} else if ( kind == TK_QDESCR ) {
-		res = LDAP_CALLOC(2,sizeof(char *));
-		if ( !res ) {
+	} else if (kind == TK_QDESCR) {
+		res = LDAP_CALLOC(2,sizeof(gchar *));
+		if (!res) {
 			*code = LDAP_SCHERR_OUTOFMEM;
 			return NULL;
 		}
@@ -370,15 +382,15 @@ parse_qdescrs(const char **sp, int *code)
 }
 
 /* Parse a woid or a $-separated list of them enclosed in () */
-static char **
-parse_oids(const char **sp, int *code, const int allow_quoted)
+static gchar **
+parse_oids(const gchar **sp, gint *code, const gint allow_quoted)
 {
-	char ** res;
-	char ** res1;
-	int kind;
-	char * sval;
-	int size;
-	int pos;
+	gchar ** res;
+	gchar ** res1;
+	gint kind;
+	gchar * sval;
+	gint size;
+	gint pos;
 
 	/*
 	 * Strictly speaking, doing this here accepts whsp before the
@@ -388,11 +400,11 @@ parse_oids(const char **sp, int *code, const int allow_quoted)
 	 */
 	parse_whsp(sp);
 	kind = get_token(sp,&sval);
-	if ( kind == TK_LEFTPAREN ) {
+	if (kind == TK_LEFTPAREN) {
 		/* Let's presume there will be at least 2 entries */
 		size = 3;
-		res = LDAP_CALLOC(3,sizeof(char *));
-		if ( !res ) {
+		res = LDAP_CALLOC(3,sizeof(gchar *));
+		if (!res) {
 			*code = LDAP_SCHERR_OUTOFMEM;
 			return NULL;
 		}
@@ -412,18 +424,18 @@ parse_oids(const char **sp, int *code, const int allow_quoted)
 		parse_whsp(sp);
 		while (1) {
 			kind = get_token(sp,&sval);
-			if ( kind == TK_RIGHTPAREN )
+			if (kind == TK_RIGHTPAREN)
 				break;
-			if ( kind == TK_DOLLAR ) {
+			if (kind == TK_DOLLAR) {
 				parse_whsp(sp);
 				kind = get_token(sp,&sval);
 				if ( kind == TK_BAREWORD ||
 				     ( allow_quoted &&
 				       kind == TK_QDSTRING ) ) {
-					if ( pos == size-2 ) {
+					if (pos == size-2) {
 						size++;
-						res1 = LDAP_REALLOC(res,size*sizeof(char *));
-						if ( !res1 ) {
+						res1 = LDAP_REALLOC(res,size*sizeof(gchar *));
+						if (!res1) {
 							LDAP_FREE(sval);
 							LDAP_VFREE(res);
 							*code = LDAP_SCHERR_OUTOFMEM;
@@ -451,8 +463,8 @@ parse_oids(const char **sp, int *code, const int allow_quoted)
 		return(res);
 	} else if ( kind == TK_BAREWORD ||
 		    ( allow_quoted && kind == TK_QDSTRING ) ) {
-		res = LDAP_CALLOC(2,sizeof(char *));
-		if ( !res ) {
+		res = LDAP_CALLOC(2,sizeof(gchar *));
+		if (!res) {
 			LDAP_FREE(sval);
 			*code = LDAP_SCHERR_OUTOFMEM;
 			return NULL;
@@ -481,26 +493,26 @@ ldap_objectclass_free(LDAPObjectClass * oc)
 }
 
 static LDAPObjectClass *
-ldap_str2objectclass( LDAP_CONST char * s,
-	int * code,
-	LDAP_CONST char ** errp,
+ldap_str2objectclass( LDAP_CONST gchar * s,
+	gint * code,
+	LDAP_CONST gchar ** errp,
 	LDAP_CONST unsigned flags )
 {
-	int kind;
-	const char * ss = s;
-	char * sval;
-	int seen_name = 0;
-	int seen_desc = 0;
-	int seen_obsolete = 0;
-	int seen_sup = 0;
-	int seen_kind = 0;
-	int seen_must = 0;
-	int seen_may = 0;
+	gint kind;
+	const gchar * ss = s;
+	gchar * sval;
+	gint seen_name = 0;
+	gint seen_desc = 0;
+	gint seen_obsolete = 0;
+	gint seen_sup = 0;
+	gint seen_kind = 0;
+	gint seen_must = 0;
+	gint seen_may = 0;
 	LDAPObjectClass * oc;
-	char ** ext_vals;
-	const char * savepos;
+	gchar ** ext_vals;
+	const gchar * savepos;
 
-	if ( !s ) {
+	if (!s) {
 		*code = LDAP_SCHERR_EMPTY;
 		*errp = "";
 		return NULL;
@@ -509,14 +521,14 @@ ldap_str2objectclass( LDAP_CONST char * s,
 	*errp = s;
 	oc = LDAP_CALLOC(1,sizeof(LDAPObjectClass));
 
-	if ( !oc ) {
+	if (!oc) {
 		*code = LDAP_SCHERR_OUTOFMEM;
 		return NULL;
 	}
 	oc->oc_kind = LDAP_SCHEMA_STRUCTURAL;
 
 	kind = get_token(&ss,&sval);
-	if ( kind != TK_LEFTPAREN ) {
+	if (kind != TK_LEFTPAREN) {
 		*code = LDAP_SCHERR_NOLEFTPAREN;
 		LDAP_FREE(sval);
 		ldap_objectclass_free(oc);
@@ -533,12 +545,12 @@ ldap_str2objectclass( LDAP_CONST char * s,
 	parse_whsp(&ss);
 	savepos = ss;
 	oc->oc_oid = ldap_int_parse_numericoid(&ss,code,0);
-	if ( !oc->oc_oid ) {
-		if ( (flags & LDAP_SCHEMA_ALLOW_ALL) && (ss == savepos) ) {
+	if (!oc->oc_oid) {
+		if ((flags & LDAP_SCHEMA_ALLOW_ALL) && (ss == savepos)) {
 			/* Backtracking */
 			ss = savepos;
 			kind = get_token(&ss,&sval);
-			if ( kind == TK_BAREWORD ) {
+			if (kind == TK_BAREWORD) {
 				if ( !strcasecmp(sval, "NAME") ||
 				     !strcasecmp(sval, "DESC") ||
 				     !strcasecmp(sval, "OBSOLETE") ||
@@ -554,7 +566,7 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				} else if ( flags &
 					LDAP_SCHEMA_ALLOW_OID_MACRO ) {
 					/* Non-numerical OID, ignore */
-					int len = ss-savepos;
+					gint len = ss-savepos;
 					oc->oc_oid = LDAP_MALLOC(len+1);
 					strncpy(oc->oc_oid, savepos, len);
 					oc->oc_oid[len] = 0;
@@ -584,9 +596,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 		case TK_RIGHTPAREN:
 			return oc;
 		case TK_BAREWORD:
-			if ( !strcasecmp(sval,"NAME") ) {
+			if (!strcasecmp(sval,"NAME")) {
 				LDAP_FREE(sval);
-				if ( seen_name ) {
+				if (seen_name) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -594,16 +606,16 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				}
 				seen_name = 1;
 				oc->oc_names = parse_qdescrs(&ss,code);
-				if ( !oc->oc_names ) {
-					if ( *code != LDAP_SCHERR_OUTOFMEM )
+				if (!oc->oc_names) {
+					if (*code != LDAP_SCHERR_OUTOFMEM)
 						*code = LDAP_SCHERR_BADNAME;
 					*errp = ss;
 					ldap_objectclass_free(oc);
 					return NULL;
 				}
-			} else if ( !strcasecmp(sval,"DESC") ) {
+			} else if (!strcasecmp(sval,"DESC")) {
 				LDAP_FREE(sval);
-				if ( seen_desc ) {
+				if (seen_desc) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -612,7 +624,7 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				seen_desc = 1;
 				parse_whsp(&ss);
 				kind = get_token(&ss,&sval);
-				if ( kind != TK_QDSTRING ) {
+				if (kind != TK_QDSTRING) {
 					*code = LDAP_SCHERR_UNEXPTOKEN;
 					*errp = ss;
 					LDAP_FREE(sval);
@@ -621,9 +633,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				}
 				oc->oc_desc = sval;
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"OBSOLETE") ) {
+			} else if (!strcasecmp(sval,"OBSOLETE")) {
 				LDAP_FREE(sval);
-				if ( seen_obsolete ) {
+				if (seen_obsolete) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -632,9 +644,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				seen_obsolete = 1;
 				oc->oc_obsolete = LDAP_SCHEMA_YES;
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"SUP") ) {
+			} else if (!strcasecmp(sval,"SUP")) {
 				LDAP_FREE(sval);
-				if ( seen_sup ) {
+				if (seen_sup) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -644,14 +656,14 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				oc->oc_sup_oids = parse_oids(&ss,
 							     code,
 							     flags);
-				if ( !oc->oc_sup_oids ) {
+				if (!oc->oc_sup_oids) {
 					*errp = ss;
 					ldap_objectclass_free(oc);
 					return NULL;
 				}
-			} else if ( !strcasecmp(sval,"ABSTRACT") ) {
+			} else if (!strcasecmp(sval,"ABSTRACT")) {
 				LDAP_FREE(sval);
-				if ( seen_kind ) {
+				if (seen_kind) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -660,9 +672,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				seen_kind = 1;
 				oc->oc_kind = LDAP_SCHEMA_ABSTRACT;
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"STRUCTURAL") ) {
+			} else if (!strcasecmp(sval,"STRUCTURAL")) {
 				LDAP_FREE(sval);
-				if ( seen_kind ) {
+				if (seen_kind) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -671,9 +683,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				seen_kind = 1;
 				oc->oc_kind = LDAP_SCHEMA_STRUCTURAL;
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"AUXILIARY") ) {
+			} else if (!strcasecmp(sval,"AUXILIARY")) {
 				LDAP_FREE(sval);
-				if ( seen_kind ) {
+				if (seen_kind) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -682,9 +694,9 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				seen_kind = 1;
 				oc->oc_kind = LDAP_SCHEMA_AUXILIARY;
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"MUST") ) {
+			} else if (!strcasecmp(sval,"MUST")) {
 				LDAP_FREE(sval);
-				if ( seen_must ) {
+				if (seen_must) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -692,15 +704,15 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				}
 				seen_must = 1;
 				oc->oc_at_oids_must = parse_oids(&ss,code,0);
-				if ( !oc->oc_at_oids_must ) {
+				if (!oc->oc_at_oids_must) {
 					*errp = ss;
 					ldap_objectclass_free(oc);
 					return NULL;
 				}
 				parse_whsp(&ss);
-			} else if ( !strcasecmp(sval,"MAY") ) {
+			} else if (!strcasecmp(sval,"MAY")) {
 				LDAP_FREE(sval);
-				if ( seen_may ) {
+				if (seen_may) {
 					*code = LDAP_SCHERR_DUPOPT;
 					*errp = ss;
 					ldap_objectclass_free(oc);
@@ -708,16 +720,16 @@ ldap_str2objectclass( LDAP_CONST char * s,
 				}
 				seen_may = 1;
 				oc->oc_at_oids_may = parse_oids(&ss,code,0);
-				if ( !oc->oc_at_oids_may ) {
+				if (!oc->oc_at_oids_may) {
 					*errp = ss;
 					ldap_objectclass_free(oc);
 					return NULL;
 				}
 				parse_whsp(&ss);
-			} else if ( sval[0] == 'X' && sval[1] == '-' ) {
+			} else if (sval[0] == 'X' && sval[1] == '-') {
 				/* Should be parse_qdstrings */
 				ext_vals = parse_qdescrs(&ss, code);
-				if ( !ext_vals ) {
+				if (!ext_vals) {
 					*errp = ss;
 					ldap_objectclass_free(oc);
 					return NULL;
@@ -757,73 +769,73 @@ ldap_str2objectclass( LDAP_CONST char * s,
 #define LDAP_UTF8_INCR(p) ((p)=LDAP_UTF8_NEXT((p)))
 #define ldap_x_utf8_to_ucs4(str) g_utf8_get_char(str)
 
-static char *ldap_utf8_strchr( const char *str, const char *chr )
+static gchar *ldap_utf8_strchr( const gchar *str, const gchar *chr )
 {
-	for( ; *str != '\0'; LDAP_UTF8_INCR(str) ) {
-		if( ldap_x_utf8_to_ucs4( str ) == ldap_x_utf8_to_ucs4( chr ) ) {
-			return (char *) str;
-		} 
+	for (; *str != '\0'; LDAP_UTF8_INCR(str) ) {
+		if (ldap_x_utf8_to_ucs4( str ) == ldap_x_utf8_to_ucs4( chr )) {
+			return (gchar *) str;
+		}
 	}
 
 	return NULL;
 }
 
-static size_t ldap_utf8_strcspn( const char *str, const char *set )
+static gsize ldap_utf8_strcspn( const gchar *str, const gchar *set )
 {
-	const char *cstr;
-	const char *cset;
+	const gchar *cstr;
+	const gchar *cset;
 
-	for( cstr = str; *cstr != '\0'; LDAP_UTF8_INCR(cstr) ) {
-		for( cset = set; *cset != '\0'; LDAP_UTF8_INCR(cset) ) {
-			if( ldap_x_utf8_to_ucs4( cstr ) == ldap_x_utf8_to_ucs4( cset ) ) {
+	for ( cstr = str; *cstr != '\0'; LDAP_UTF8_INCR(cstr) ) {
+		for ( cset = set; *cset != '\0'; LDAP_UTF8_INCR(cset) ) {
+			if (ldap_x_utf8_to_ucs4( cstr ) == ldap_x_utf8_to_ucs4( cset )) {
 				return cstr - str;
-			} 
+			}
 		}
 	}
 
 	return cstr - str;
 }
 
-static size_t ldap_utf8_strspn( const char *str, const char *set )
+static gsize ldap_utf8_strspn( const gchar *str, const gchar *set )
 {
-	const char *cstr;
-	const char *cset;
+	const gchar *cstr;
+	const gchar *cset;
 
-	for( cstr = str; *cstr != '\0'; LDAP_UTF8_INCR(cstr) ) {
-		for( cset = set; ; LDAP_UTF8_INCR(cset) ) {
-			if( *cset == '\0' ) {
+	for ( cstr = str; *cstr != '\0'; LDAP_UTF8_INCR(cstr) ) {
+		for ( cset = set; ; LDAP_UTF8_INCR(cset) ) {
+			if (*cset == '\0') {
 				return cstr - str;
 			}
 
-			if( ldap_x_utf8_to_ucs4( cstr ) == ldap_x_utf8_to_ucs4( cset ) ) {
+			if (ldap_x_utf8_to_ucs4( cstr ) == ldap_x_utf8_to_ucs4( cset )) {
 				break;
-			} 
+			}
 		}
 	}
 
 	return cstr - str;
 }
 
-static char *ldap_utf8_strtok(char *str, const char *sep, char **last)
+static gchar *ldap_utf8_strtok(gchar *str, const gchar *sep, gchar **last)
 {
-	char *begin;
-	char *end;
+	gchar *begin;
+	gchar *end;
 
-	if( last == NULL ) return NULL;
+	if (last == NULL) return NULL;
 
 	begin = str ? str : *last;
 
 	begin += ldap_utf8_strspn( begin, sep );
 
-	if( *begin == '\0' ) {
+	if (*begin == '\0') {
 		*last = NULL;
 		return NULL;
 	}
 
 	end = &begin[ ldap_utf8_strcspn( begin, sep ) ];
 
-	if( *end != '\0' ) {
-		char *next = LDAP_UTF8_NEXT( end );
+	if (*end != '\0') {
+		gchar *next = LDAP_UTF8_NEXT( end );
 		*end = '\0';
 		end = next;
 	}
@@ -859,39 +871,39 @@ static char *ldap_utf8_strtok(char *str, const char *sep, char **last)
 
 typedef struct ldap_url_desc {
 	struct ldap_url_desc *lud_next;
-	char	*lud_scheme;
-	char	*lud_host;
-	int		lud_port;
-	char	*lud_dn;
-	char	**lud_attrs;
-	int		lud_scope;
-	char	*lud_filter;
-	char	**lud_exts;
-	int		lud_crit_exts;
+	gchar	*lud_scheme;
+	gchar	*lud_host;
+	gint		lud_port;
+	gchar	*lud_dn;
+	gchar	**lud_attrs;
+	gint		lud_scope;
+	gchar	*lud_filter;
+	gchar	**lud_exts;
+	gint		lud_crit_exts;
 } LDAPURLDesc;
 
 /* from url.c */
 
-static const char*
+static const gchar *
 skip_url_prefix(
-	const char *url,
-	int *enclosedp,
-	const char **scheme )
+	const gchar *url,
+	gint *enclosedp,
+	const gchar **scheme )
 {
 	/*
- 	 * return non-zero if this looks like a LDAP URL; zero if not
- 	 * if non-zero returned, *urlp will be moved past "ldap://" part of URL
- 	 */
-	const char *p;
+	 * return non-zero if this looks like a LDAP URL; zero if not
+	 * if non-zero returned, *urlp will be moved past "ldap://" part of URL
+	 */
+	const gchar *p;
 
-	if ( url == NULL ) {
+	if (url == NULL) {
 		return( NULL );
 	}
 
 	p = url;
 
 	/* skip leading '<' (if any) */
-	if ( *p == '<' ) {
+	if (*p == '<') {
 		*enclosedp = 1;
 		++p;
 	} else {
@@ -899,12 +911,12 @@ skip_url_prefix(
 	}
 
 	/* skip leading "URL:" (if any) */
-	if ( strncasecmp( p, LDAP_URL_URLCOLON, LDAP_URL_URLCOLON_LEN ) == 0 ) {
+	if (strncasecmp( p, LDAP_URL_URLCOLON, LDAP_URL_URLCOLON_LEN ) == 0) {
 		p += LDAP_URL_URLCOLON_LEN;
 	}
 
 	/* check for "ldap://" prefix */
-	if ( strncasecmp( p, LDAP_URL_PREFIX, LDAP_URL_PREFIX_LEN ) == 0 ) {
+	if (strncasecmp( p, LDAP_URL_PREFIX, LDAP_URL_PREFIX_LEN ) == 0) {
 		/* skip over "ldap://" prefix and return success */
 		p += LDAP_URL_PREFIX_LEN;
 		*scheme = "ldap";
@@ -912,7 +924,7 @@ skip_url_prefix(
 	}
 
 	/* check for "ldaps://" prefix */
-	if ( strncasecmp( p, LDAPS_URL_PREFIX, LDAPS_URL_PREFIX_LEN ) == 0 ) {
+	if (strncasecmp( p, LDAPS_URL_PREFIX, LDAPS_URL_PREFIX_LEN ) == 0) {
 		/* skip over "ldaps://" prefix and return success */
 		p += LDAPS_URL_PREFIX_LEN;
 		*scheme = "ldaps";
@@ -920,7 +932,7 @@ skip_url_prefix(
 	}
 
 	/* check for "ldapi://" prefix */
-	if ( strncasecmp( p, LDAPI_URL_PREFIX, LDAPI_URL_PREFIX_LEN ) == 0 ) {
+	if (strncasecmp( p, LDAPI_URL_PREFIX, LDAPI_URL_PREFIX_LEN ) == 0) {
 		/* skip over "ldapi://" prefix and return success */
 		p += LDAPI_URL_PREFIX_LEN;
 		*scheme = "ldapi";
@@ -929,7 +941,7 @@ skip_url_prefix(
 
 #ifdef LDAP_CONNECTIONLESS
 	/* check for "cldap://" prefix */
-	if ( strncasecmp( p, LDAPC_URL_PREFIX, LDAPC_URL_PREFIX_LEN ) == 0 ) {
+	if (strncasecmp( p, LDAPC_URL_PREFIX, LDAPC_URL_PREFIX_LEN ) == 0) {
 		/* skip over "cldap://" prefix and return success */
 		p += LDAPC_URL_PREFIX_LEN;
 		*scheme = "cldap";
@@ -940,21 +952,21 @@ skip_url_prefix(
 	return( NULL );
 }
 
-static int str2scope( const char *p )
+static gint str2scope( const gchar *p )
 {
-	if ( strcasecmp( p, "one" ) == 0 ) {
+	if (strcasecmp( p, "one" ) == 0) {
 		return LDAP_SCOPE_ONELEVEL;
 
-	} else if ( strcasecmp( p, "onelevel" ) == 0 ) {
+	} else if (strcasecmp( p, "onelevel" ) == 0) {
 		return LDAP_SCOPE_ONELEVEL;
 
-	} else if ( strcasecmp( p, "base" ) == 0 ) {
+	} else if (strcasecmp( p, "base" ) == 0) {
 		return LDAP_SCOPE_BASE;
 
-	} else if ( strcasecmp( p, "sub" ) == 0 ) {
+	} else if (strcasecmp( p, "sub" ) == 0) {
 		return LDAP_SCOPE_SUBTREE;
 
-	} else if ( strcasecmp( p, "subtree" ) == 0 ) {
+	} else if (strcasecmp( p, "subtree" ) == 0) {
 		return LDAP_SCOPE_SUBTREE;
 	}
 
@@ -964,39 +976,39 @@ static int str2scope( const char *p )
 static void
 ldap_free_urldesc( LDAPURLDesc *ludp )
 {
-	if ( ludp == NULL ) {
+	if (ludp == NULL) {
 		return;
 	}
-	
-	if ( ludp->lud_scheme != NULL ) {
+
+	if (ludp->lud_scheme != NULL) {
 		LDAP_FREE( ludp->lud_scheme );
 	}
 
-	if ( ludp->lud_host != NULL ) {
+	if (ludp->lud_host != NULL) {
 		LDAP_FREE( ludp->lud_host );
 	}
 
-	if ( ludp->lud_dn != NULL ) {
+	if (ludp->lud_dn != NULL) {
 		LDAP_FREE( ludp->lud_dn );
 	}
 
-	if ( ludp->lud_filter != NULL ) {
+	if (ludp->lud_filter != NULL) {
 		LDAP_FREE( ludp->lud_filter);
 	}
 
-	if ( ludp->lud_attrs != NULL ) {
+	if (ludp->lud_attrs != NULL) {
 		LDAP_VFREE( ludp->lud_attrs );
 	}
 
-	if ( ludp->lud_exts != NULL ) {
+	if (ludp->lud_exts != NULL) {
 		LDAP_VFREE( ludp->lud_exts );
 	}
 
 	LDAP_FREE( ludp );
 }
 
-static int
-ldap_int_unhex( int c )
+static gint
+ldap_int_unhex( gint c )
 {
 	return( c >= '0' && c <= '9' ? c - '0'
 	    : c >= 'A' && c <= 'F' ? c - 'A' + 10
@@ -1004,21 +1016,21 @@ ldap_int_unhex( int c )
 }
 
 static void
-ldap_pvt_hex_unescape( char *s )
+ldap_pvt_hex_unescape( gchar *s )
 {
 	/*
 	 * Remove URL hex escapes from s... done in place.  The basic concept for
 	 * this routine is borrowed from the WWW library HTUnEscape() routine.
 	 */
-	char	*p;
+	gchar	*p;
 
 	for ( p = s; *s != '\0'; ++s ) {
-		if ( *s == '%' ) {
-			if ( *++s == '\0' ) {
+		if (*s == '%') {
+			if (*++s == '\0') {
 				break;
 			}
 			*p = ldap_int_unhex( *s ) << 4;
-			if ( *++s == '\0' ) {
+			if (*++s == '\0') {
 				break;
 			}
 			*p++ += ldap_int_unhex( *s );
@@ -1030,30 +1042,30 @@ ldap_pvt_hex_unescape( char *s )
 	*p = '\0';
 }
 
-static char **
-ldap_str2charray( const char *str_in, const char *brkstr )
+static gchar **
+ldap_str2charray( const gchar *str_in, const gchar *brkstr )
 {
-	char	**res;
-	char	*str, *s;
-	char	*lasts;
-	int	i;
+	gchar	**res;
+	gchar	*str, *s;
+	gchar	*lasts;
+	gint	i;
 
 	/* protect the input string from strtok */
 	str = LDAP_STRDUP( str_in );
-	if( str == NULL ) {
+	if (str == NULL) {
 		return NULL;
 	}
 
 	i = 1;
 	for ( s = str; *s; s++ ) {
-		if ( ldap_utf8_strchr( brkstr, s ) != NULL ) {
+		if (ldap_utf8_strchr( brkstr, s ) != NULL) {
 			i++;
 		}
 	}
 
-	res = (char **) LDAP_MALLOC( (i + 1) * sizeof(char *) );
+	res = (gchar **) LDAP_MALLOC( (i + 1) * sizeof(gchar *) );
 
-	if( res == NULL ) {
+	if (res == NULL) {
 		LDAP_FREE( str );
 		return NULL;
 	}
@@ -1066,8 +1078,8 @@ ldap_str2charray( const char *str_in, const char *brkstr )
 	{
 		res[i] = LDAP_STRDUP( s );
 
-		if(res[i] == NULL) {
-			for( --i ; i >= 0 ; i-- ) {
+		if (res[i] == NULL) {
+			for ( --i; i >= 0; i-- ) {
 				LDAP_FREE( res[i] );
 			}
 			LDAP_FREE( res );
@@ -1084,21 +1096,21 @@ ldap_str2charray( const char *str_in, const char *brkstr )
 	return( res );
 }
 
-static int
-ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
+static gint
+ldap_url_parse_ext( LDAP_CONST gchar *url_in, LDAPURLDesc **ludpp )
 {
 /*
  *  Pick apart the pieces of an LDAP URL.
  */
 
 	LDAPURLDesc	*ludp;
-	char	*p, *q, *r;
-	int		i, enclosed;
-	const char *scheme = NULL;
-	const char *url_tmp;
-	char *url;
+	gchar	*p, *q, *r;
+	gint		i, enclosed;
+	const gchar *scheme = NULL;
+	const gchar *url_tmp;
+	gchar *url;
 
-	if( url_in == NULL || ludpp == NULL ) {
+	if (url_in == NULL || ludpp == NULL) {
 		return LDAP_URL_ERR_PARAM;
 	}
 
@@ -1106,7 +1118,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 
 	url_tmp = skip_url_prefix( url_in, &enclosed, &scheme );
 
-	if ( url_tmp == NULL ) {
+	if (url_tmp == NULL) {
 		return LDAP_URL_ERR_BADSCHEME;
 	}
 
@@ -1114,14 +1126,14 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 
 	/* make working copy of the remainder of the URL */
 	url = LDAP_STRDUP( url_tmp );
-	if ( url == NULL ) {
+	if (url == NULL) {
 		return LDAP_URL_ERR_MEM;
 	}
 
-	if ( enclosed ) {
+	if (enclosed) {
 		p = &url[strlen(url)-1];
 
-		if( *p != '>' ) {
+		if (*p != '>') {
 			LDAP_FREE( url );
 			return LDAP_URL_ERR_BADENCLOSURE;
 		}
@@ -1132,7 +1144,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	/* allocate return struct */
 	ludp = (LDAPURLDesc *)LDAP_CALLOC( 1, sizeof( LDAPURLDesc ));
 
-	if ( ludp == NULL ) {
+	if (ludp == NULL) {
 		LDAP_FREE( url );
 		return LDAP_URL_ERR_MEM;
 	}
@@ -1149,7 +1161,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 
 	ludp->lud_scheme = LDAP_STRDUP( scheme );
 
-	if ( ludp->lud_scheme == NULL ) {
+	if (ludp->lud_scheme == NULL) {
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
 		return LDAP_URL_ERR_MEM;
@@ -1158,15 +1170,15 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	/* scan forward for '/' that marks end of hostport and begin. of dn */
 	p = strchr( url, '/' );
 
-	if( p != NULL ) {
+	if (p != NULL) {
 		/* terminate hostport; point to start of dn */
 		*p++ = '\0';
 	}
 
 	/* IPv6 syntax with [ip address]:port */
-	if ( *url == '[' ) {
+	if (*url == '[') {
 		r = strchr( url, ']' );
-		if ( r == NULL ) {
+		if (r == NULL) {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_BADURL;
@@ -1177,20 +1189,20 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 		q = strchr( url, ':' );
 	}
 
-	if ( q != NULL ) {
-		char	*next;
+	if (q != NULL) {
+		gchar	*next;
 
 		*q++ = '\0';
 		ldap_pvt_hex_unescape( q );
 
-		if( *q == '\0' ) {
+		if (*q == '\0') {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_BADURL;
 		}
 
 		ludp->lud_port = strtol( q, &next, 10 );
-		if ( next == NULL || next[0] != '\0' ) {
+		if (next == NULL || next[0] != '\0') {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_BADURL;
@@ -1202,7 +1214,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	/* If [ip address]:port syntax, url is [ip and we skip the [ */
 	ludp->lud_host = LDAP_STRDUP( url + ( *url == '[' ) );
 
-	if( ludp->lud_host == NULL ) {
+	if (ludp->lud_host == NULL) {
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
 		return LDAP_URL_ERR_MEM;
@@ -1217,12 +1229,12 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	 * but we need to account for it. Fortunately it can't be confused with
 	 * anything real.
 	 */
-	if( (p == NULL) && (q != NULL) && ((q = strchr( q, '?')) != NULL)) {
-		q++;		
+	if ( (p == NULL) && (q != NULL) && ((q = strchr( q, '?')) != NULL)) {
+		q++;
 		/* ? immediately followed by question */
-		if( *q == '?') {
+		if ( *q == '?') {
 			q++;
-			if( *q != '\0' ) {
+			if (*q != '\0') {
 				/* parse dn part */
 				ldap_pvt_hex_unescape( q );
 				ludp->lud_dn = LDAP_STRDUP( q );
@@ -1230,7 +1242,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 				ludp->lud_dn = LDAP_STRDUP( "" );
 			}
 
-			if( ludp->lud_dn == NULL ) {
+			if (ludp->lud_dn == NULL) {
 				LDAP_FREE( url );
 				ldap_free_urldesc( ludp );
 				return LDAP_URL_ERR_MEM;
@@ -1238,7 +1250,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 		}
 	}
 
-	if( p == NULL ) {
+	if (p == NULL) {
 		LDAP_FREE( url );
 		*ludpp = ludp;
 		return LDAP_URL_SUCCESS;
@@ -1247,12 +1259,12 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	/* scan forward for '?' that may marks end of dn */
 	q = strchr( p, '?' );
 
-	if( q != NULL ) {
+	if (q != NULL) {
 		/* terminate dn part */
 		*q++ = '\0';
 	}
 
-	if( *p != '\0' ) {
+	if (*p != '\0') {
 		/* parse dn part */
 		ldap_pvt_hex_unescape( p );
 		ludp->lud_dn = LDAP_STRDUP( p );
@@ -1260,13 +1272,13 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 		ludp->lud_dn = LDAP_STRDUP( "" );
 	}
 
-	if( ludp->lud_dn == NULL ) {
+	if (ludp->lud_dn == NULL) {
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
 		return LDAP_URL_ERR_MEM;
 	}
 
-	if( q == NULL ) {
+	if (q == NULL) {
 		/* no more */
 		LDAP_FREE( url );
 		*ludpp = ludp;
@@ -1277,24 +1289,24 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	p = q;
 	q = strchr( p, '?' );
 
-	if( q != NULL ) {
+	if (q != NULL) {
 		/* terminate attributes part */
 		*q++ = '\0';
 	}
 
-	if( *p != '\0' ) {
+	if (*p != '\0') {
 		/* parse attributes */
 		ldap_pvt_hex_unescape( p );
 		ludp->lud_attrs = ldap_str2charray( p, "," );
 
-		if( ludp->lud_attrs == NULL ) {
+		if (ludp->lud_attrs == NULL) {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_BADATTRS;
 		}
 	}
 
-	if ( q == NULL ) {
+	if (q == NULL) {
 		/* no more */
 		LDAP_FREE( url );
 		*ludpp = ludp;
@@ -1305,24 +1317,24 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	p = q;
 	q = strchr( p, '?' );
 
-	if( q != NULL ) {
+	if (q != NULL) {
 		/* terminate the scope part */
 		*q++ = '\0';
 	}
 
-	if( *p != '\0' ) {
+	if (*p != '\0') {
 		/* parse the scope */
 		ldap_pvt_hex_unescape( p );
 		ludp->lud_scope = str2scope( p );
 
-		if( ludp->lud_scope == -1 ) {
+		if (ludp->lud_scope == -1) {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_BADSCOPE;
 		}
 	}
 
-	if ( q == NULL ) {
+	if (q == NULL) {
 		/* no more */
 		LDAP_FREE( url );
 		*ludpp = ludp;
@@ -1333,16 +1345,16 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	p = q;
 	q = strchr( p, '?' );
 
-	if( q != NULL ) {
+	if (q != NULL) {
 		/* terminate the filter part */
 		*q++ = '\0';
 	}
 
-	if( *p != '\0' ) {
+	if (*p != '\0') {
 		/* parse the filter */
 		ldap_pvt_hex_unescape( p );
 
-		if( ! *p ) {
+		if (!*p) {
 			/* missing filter */
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
@@ -1352,14 +1364,14 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 		LDAP_FREE( ludp->lud_filter );
 		ludp->lud_filter = LDAP_STRDUP( p );
 
-		if( ludp->lud_filter == NULL ) {
+		if (ludp->lud_filter == NULL) {
 			LDAP_FREE( url );
 			ldap_free_urldesc( ludp );
 			return LDAP_URL_ERR_MEM;
 		}
 	}
 
-	if ( q == NULL ) {
+	if (q == NULL) {
 		/* no more */
 		LDAP_FREE( url );
 		*ludpp = ludp;
@@ -1370,7 +1382,7 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	p = q;
 	q = strchr( p, '?' );
 
-	if( q != NULL ) {
+	if (q != NULL) {
 		/* extra '?' */
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
@@ -1380,22 +1392,22 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	/* parse the extensions */
 	ludp->lud_exts = ldap_str2charray( p, "," );
 
-	if( ludp->lud_exts == NULL ) {
+	if (ludp->lud_exts == NULL) {
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
 		return LDAP_URL_ERR_BADEXTS;
 	}
 
-	for( i=0; ludp->lud_exts[i] != NULL; i++ ) {
+	for ( i=0; ludp->lud_exts[i] != NULL; i++ ) {
 		ldap_pvt_hex_unescape( ludp->lud_exts[i] );
 
-		if( *ludp->lud_exts[i] == '!' ) {
+		if (*ludp->lud_exts[i] == '!') {
 			/* count the number of critical extensions */
 			ludp->lud_crit_exts++;
 		}
 	}
 
-	if( i == 0 ) {
+	if (i == 0) {
 		/* must have 1 or more */
 		LDAP_FREE( url );
 		ldap_free_urldesc( ludp );
@@ -1408,12 +1420,12 @@ ldap_url_parse_ext( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	return LDAP_URL_SUCCESS;
 }
 
-static int
-ldap_url_parse( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
+static gint
+ldap_url_parse( LDAP_CONST gchar *url_in, LDAPURLDesc **ludpp )
 {
-	int rc = ldap_url_parse_ext( url_in, ludpp );
+	gint rc = ldap_url_parse_ext( url_in, ludpp );
 
-	if( rc != LDAP_URL_SUCCESS ) {
+	if (rc != LDAP_URL_SUCCESS) {
 		return rc;
 	}
 
@@ -1427,13 +1439,13 @@ ldap_url_parse( LDAP_CONST char *url_in, LDAPURLDesc **ludpp )
 	}
 
 	if ((*ludpp)->lud_port == 0) {
-		if( strcmp((*ludpp)->lud_scheme, "ldap") == 0 ) {
+		if (strcmp((*ludpp)->lud_scheme, "ldap") == 0) {
 			(*ludpp)->lud_port = LDAP_PORT;
 #ifdef LDAP_CONNECTIONLESS
-		} else if( strcmp((*ludpp)->lud_scheme, "cldap") == 0 ) {
+		} else if (strcmp((*ludpp)->lud_scheme, "cldap") == 0) {
 			(*ludpp)->lud_port = LDAP_PORT;
 #endif
-		} else if( strcmp((*ludpp)->lud_scheme, "ldaps") == 0 ) {
+		} else if (strcmp((*ludpp)->lud_scheme, "ldaps") == 0) {
 			(*ludpp)->lud_port = LDAPS_PORT;
 		}
 	}
