@@ -35,12 +35,14 @@
 
 #ifdef G_OS_WIN32
 #include "libedataserver/e-data-server-util.h"
-#undef EVOLUTION_LOCALEDIR
-#define EVOLUTION_LOCALEDIR e_util_get_localedir ()
+#undef LOCALEDIR
+#define LOCALEDIR e_util_get_localedir ()
 #endif
 
 #define d(x)
 
+G_DEFINE_TYPE (EContact, e_contact, E_TYPE_VCARD)
+
 struct _EContactPrivate {
 	gchar *cached_strings [E_CONTACT_FIELD_LAST];
 };
@@ -374,30 +376,6 @@ e_contact_init (EContact *ec)
 	ec->priv = g_new0 (EContactPrivate, 1);
 }
 
-GType
-e_contact_get_type (void)
-{
-	static GType contact_type = 0;
-
-	if (!contact_type) {
-		static const GTypeInfo contact_info =  {
-			sizeof (EContactClass),
-			NULL,           /* base_init */
-			NULL,           /* base_finalize */
-			(GClassInitFunc) e_contact_class_init,
-			NULL,           /* class_finalize */
-			NULL,           /* class_data */
-			sizeof (EContact),
-			0,             /* n_preallocs */
-			(GInstanceInitFunc) e_contact_init,
-		};
-
-		contact_type = g_type_register_static (E_TYPE_VCARD, "EContact", &contact_info, 0);
-	}
-
-	return contact_type;
-}
-
 static EVCardAttribute*
 e_contact_get_first_attr (EContact *contact, const gchar *attr_name)
 {
@@ -1217,7 +1195,7 @@ e_contact_get_property (GObject *object,
  *
  * Creates a new, blank #EContact.
  *
- * Return value: A new #EContact.
+ * Returns: A new #EContact.
  **/
 EContact*
 e_contact_new (void)
@@ -1231,7 +1209,7 @@ e_contact_new (void)
  *
  * Creates a new #EContact based on a vcard.
  *
- * Return value: A new #EContact.
+ * Returns: A new #EContact.
  **/
 EContact*
 e_contact_new_from_vcard  (const gchar *vcard)
@@ -1289,7 +1267,7 @@ e_contact_new_from_vcard  (const gchar *vcard)
  *
  * Creates a copy of @contact.
  *
- * Return value: A new #EContact identical to @contact.
+ * Returns: A new #EContact identical to @contact.
  **/
 EContact*
 e_contact_duplicate (EContact *contact)
@@ -1312,7 +1290,7 @@ e_contact_duplicate (EContact *contact)
  *
  * Gets the string representation of @field_id.
  *
- * Return value: The string representation of @field_id, or %NULL if it doesn't exist.
+ * Returns: The string representation of @field_id, or %NULL if it doesn't exist.
  **/
 const gchar *
 e_contact_field_name (EContactField field_id)
@@ -1329,7 +1307,7 @@ e_contact_field_name (EContactField field_id)
  * Gets a human-readable, translated string representation
  * of @field_id.
  *
- * Return value: The human-readable representation of @field_id, or %NULL if it doesn't exist.
+ * Returns: The human-readable representation of @field_id, or %NULL if it doesn't exist.
  **/
 const gchar *
 e_contact_pretty_name (EContactField field_id)
@@ -1337,7 +1315,7 @@ e_contact_pretty_name (EContactField field_id)
 	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, "");
 
 #ifdef ENABLE_NLS
-	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
@@ -1350,7 +1328,7 @@ e_contact_pretty_name (EContactField field_id)
  *
  * Gets the vcard attribute corresponding to @field_id, as a string.
  *
- * Return value: The vcard attribute corresponding to @field_id, or %NULL if it doesn't exist.
+ * Returns: The vcard attribute corresponding to @field_id, or %NULL if it doesn't exist.
  **/
 const gchar *
 e_contact_vcard_attribute  (EContactField field_id)
@@ -1366,7 +1344,7 @@ e_contact_vcard_attribute  (EContactField field_id)
  *
  * Gets the #EContactField corresponding to the @field_name.
  *
- * Return value: An #EContactField corresponding to @field_name, or %0 if it doesn't exist.
+ * Returns: An #EContactField corresponding to @field_name, or %0 if it doesn't exist.
  **/
 EContactField
 e_contact_field_id (const gchar *field_name)
@@ -1387,7 +1365,9 @@ e_contact_field_id (const gchar *field_name)
  *
  * Gets the #EContactField corresponding to the @vcard_field.
  *
- * Return value: An #EContactField corresponding to @vcard_field, or %0 if it doesn't exist.
+ * Returns: An #EContactField corresponding to @vcard_field, or %0 if it doesn't exist.
+ *
+ * Since: 2.26
  **/
 EContactField
 e_contact_field_id_from_vcard (const gchar *vcard_field)
@@ -1414,7 +1394,7 @@ e_contact_field_id_from_vcard (const gchar *vcard_field)
  *
  * Gets the value of @contact's field specified by @field_id.
  *
- * Return value: Depends on the field's type, owned by the caller.
+ * Returns: Depends on the field's type, owned by the caller.
  **/
 gpointer
 e_contact_get (EContact *contact, EContactField field_id)
@@ -1443,7 +1423,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 			GList *list = g_list_copy (e_vcard_attribute_get_values (attr));
 			GList *l;
 			for (l = list; l; l = l->next)
-				l->data = g_strdup (l->data);
+				l->data = g_strstrip (g_strdup (l->data));
 			return list;
 		}
 	}
@@ -1457,7 +1437,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 				v = e_vcard_attribute_get_values (attr);
 				v = g_list_nth (v, info->list_elem);
 
-				return v ? g_strdup (v->data) : NULL;
+				return v ? g_strstrip (g_strdup (v->data)) : NULL;
 			}
 		}
 	}
@@ -1478,7 +1458,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 					if (num_left-- == 0) {
 						GList *v = e_vcard_attribute_get_values (attr);
 
-						return v ? g_strdup (v->data) : NULL;
+						return v ? g_strstrip (g_strdup (v->data)) : NULL;
 					}
 				}
 			}
@@ -1490,7 +1470,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 		if (info->t & E_CONTACT_FIELD_TYPE_STRING) {
 			if (attr) {
 				GList *p = e_vcard_attribute_get_values (attr);
-				return g_strdup (p->data);
+				return g_strstrip (g_strdup (p->data));
 			}
 			else {
 				return NULL;
@@ -1516,7 +1496,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 		if (info->t & E_CONTACT_FIELD_TYPE_STRUCT)
 			return (gpointer)info->boxed_type_getter();
 		else
-			return g_strdup (rv);
+			return g_strstrip (g_strdup (rv));
 	}
 	else if (info->t & E_CONTACT_FIELD_TYPE_SYNTHETIC) {
 		switch (info->field_id) {
@@ -1537,7 +1517,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 					str = e_contact_get_const (contact, E_CONTACT_EMAIL_1);
 			}
 
-			return g_strdup (str);
+			return g_strstrip (g_strdup (str));
 		}
 		case E_CONTACT_CATEGORIES: {
 			EVCardAttribute *attr = e_contact_get_first_attr (contact, EVC_CATEGORIES);
@@ -1580,10 +1560,10 @@ e_contact_get (EContact *contact, EContactField field_id)
 				v = e_vcard_attribute_get_values (attr);
 
 				if (info->t & E_CONTACT_FIELD_TYPE_STRING) {
-					return v ? g_strdup (v->data) : NULL;
+					return v ? g_strstrip (g_strdup (v->data)) : NULL;
 				}
 				else {
-					rv = g_list_append (rv, v ? g_strdup (v->data) : NULL);
+					rv = g_list_append (rv, v ? g_strstrip (g_strdup (v->data)) : NULL);
 				}
 			}
 		}
@@ -1600,7 +1580,7 @@ e_contact_get (EContact *contact, EContactField field_id)
  * Gets the value of @contact's field specified by @field_id, caching
  * the result so it can be freed later.
  *
- * Return value: Depends on the field's type, owned by the #EContact.
+ * Returns: Depends on the field's type, owned by the #EContact.
  **/
 gconstpointer
 e_contact_get_const (EContact *contact, EContactField field_id)
@@ -1653,7 +1633,7 @@ e_contact_set (EContact *contact, EContactField field_id, gconstpointer value)
  *
  * Gets a list of the vcard attributes for @contact's @field_id.
  *
- * Return value: A #GList of pointers to #EVCardAttribute, owned by the caller.
+ * Returns: A #GList of pointers to #EVCardAttribute, owned by the caller.
  **/
 GList*
 e_contact_get_attributes (EContact *contact, EContactField field_id)
@@ -1714,7 +1694,7 @@ e_contact_set_attributes (EContact *contact, EContactField field_id, GList *attr
  *
  * Creates a new #EContactName struct.
  *
- * Return value: A new #EContactName struct.
+ * Returns: A new #EContactName struct.
  **/
 EContactName*
 e_contact_name_new (void)
@@ -1728,7 +1708,7 @@ e_contact_name_new (void)
  *
  * Generates a string representation of @name.
  *
- * Return value: The string representation of @name.
+ * Returns: The string representation of @name.
  **/
 gchar *
 e_contact_name_to_string(const EContactName *name)
@@ -1757,7 +1737,7 @@ e_contact_name_to_string(const EContactName *name)
  *
  * Creates a new #EContactName based on the parsed @name_str.
  *
- * Return value: A new #EContactName struct.
+ * Returns: A new #EContactName struct.
  **/
 EContactName*
 e_contact_name_from_string (const gchar *name_str)
@@ -1786,7 +1766,7 @@ e_contact_name_from_string (const gchar *name_str)
  *
  * Creates a copy of @n.
  *
- * Return value: A new #EContactName identical to @n.
+ * Returns: A new #EContactName identical to @n.
  **/
 EContactName*
 e_contact_name_copy (EContactName *n)
@@ -1827,25 +1807,34 @@ e_contact_name_free (EContactName *name)
 	g_free (name);
 }
 
-GType
-e_contact_name_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactName",
-							(GBoxedCopyFunc) e_contact_name_copy,
-							(GBoxedFreeFunc) e_contact_name_free);
-	return type_id;
+#define E_CONTACT_DEFINE_BOXED_TYPE(_tp,_nm)				\
+	GType								\
+	_tp ## _get_type (void)						\
+	{								\
+		static volatile gsize type_id__volatile = 0;		\
+									\
+		if (g_once_init_enter (&type_id__volatile)) {		\
+			GType type_id;					\
+									\
+			type_id = g_boxed_type_register_static (_nm,	\
+				(GBoxedCopyFunc) _tp ## _copy,		\
+				(GBoxedFreeFunc) _tp ## _free);		\
+									\
+			g_once_init_leave (&type_id__volatile, type_id);\
+	}								\
+									\
+	return type_id__volatile;					\
 }
 
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_name, "EContactName")
+
 /**
  * e_contact_date_from_string:
  * @str: a date string in the format YYYY-MM-DD or YYYYMMDD
  *
  * Creates a new #EContactDate based on @str.
  *
- * Return value: A new #EContactDate struct.
+ * Returns: A new #EContactDate struct.
  **/
 EContactDate*
 e_contact_date_from_string (const gchar *str)
@@ -1883,7 +1872,7 @@ e_contact_date_from_string (const gchar *str)
  * Generates a date string in the format YYYY-MM-DD based
  * on the values of @dt.
  *
- * Return value: A date string, owned by the caller.
+ * Returns: A date string, owned by the caller.
  **/
 gchar *
 e_contact_date_to_string (EContactDate *dt)
@@ -1904,7 +1893,7 @@ e_contact_date_to_string (EContactDate *dt)
  *
  * Checks if @dt1 and @dt2 are the same date.
  *
- * Return value: %TRUE if @dt1 and @dt2 are equal, %FALSE otherwise.
+ * Returns: %TRUE if @dt1 and @dt2 are equal, %FALSE otherwise.
  **/
 gboolean
 e_contact_date_equal (EContactDate *dt1, EContactDate *dt2)
@@ -1923,7 +1912,7 @@ e_contact_date_equal (EContactDate *dt1, EContactDate *dt2)
  *
  * Creates a copy of @dt.
  *
- * Return value: A new #EContactDate struct identical to @dt.
+ * Returns: A new #EContactDate struct identical to @dt.
  **/
 static EContactDate *
 e_contact_date_copy (EContactDate *dt)
@@ -1948,24 +1937,14 @@ e_contact_date_free (EContactDate *date)
 	g_free (date);
 }
 
-GType
-e_contact_date_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactDate",
-							(GBoxedCopyFunc) e_contact_date_copy,
-							(GBoxedFreeFunc) e_contact_date_free);
-	return type_id;
-}
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_date, "EContactDate")
 
 /**
  * e_contact_date_new:
  *
  * Creates a new #EContactDate struct.
  *
- * Return value: A new #EContactDate struct.
+ * Returns: A new #EContactDate struct.
  **/
 EContactDate*
 e_contact_date_new (void)
@@ -2007,7 +1986,7 @@ e_contact_photo_free (EContactPhoto *photo)
  *
  * Creates a copy of @photo.
  *
- * Return value: A new #EContactPhoto struct identical to @photo.
+ * Returns: A new #EContactPhoto struct identical to @photo.
  **/
 static EContactPhoto *
 e_contact_photo_copy (EContactPhoto *photo)
@@ -2032,23 +2011,15 @@ e_contact_photo_copy (EContactPhoto *photo)
 	return photo2;
 }
 
-GType
-e_contact_photo_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactPhoto",
-							(GBoxedCopyFunc) e_contact_photo_copy,
-							(GBoxedFreeFunc) e_contact_photo_free);
-	return type_id;
-}
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_photo, "EContactPhoto")
 
 /**
  * e_contact_geo_free:
  * @geo: an #EContactGeo
  *
  * Frees the @geo struct and its contents.
+ *
+ * Since: 1.12
  **/
 void
 e_contact_geo_free (EContactGeo *geo)
@@ -2066,17 +2037,7 @@ e_contact_geo_copy (EContactGeo *geo)
 	return geo2;
 }
 
-GType
-e_contact_geo_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactGeo",
-							(GBoxedCopyFunc) e_contact_geo_copy,
-							(GBoxedFreeFunc) e_contact_geo_free);
-	return type_id;
-}
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_geo, "EContactGeo")
 
 /**
  * e_contact_address_free:
@@ -2119,17 +2080,7 @@ e_contact_address_copy (EContactAddress *address)
 	return address2;
 }
 
-GType
-e_contact_address_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactAddress",
-							(GBoxedCopyFunc) e_contact_address_copy,
-							(GBoxedFreeFunc) e_contact_address_free);
-	return type_id;
-}
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_address, "EContactAddress")
 
 /**
  * e_contact_cert_free:
@@ -2158,14 +2109,4 @@ e_contact_cert_copy (EContactCert *cert)
 	return cert2;
 }
 
-GType
-e_contact_cert_get_type (void)
-{
-	static GType type_id = 0;
-
-	if (!type_id)
-		type_id = g_boxed_type_register_static ("EContactCert",
-							(GBoxedCopyFunc) e_contact_cert_copy,
-							(GBoxedFreeFunc) e_contact_cert_free);
-	return type_id;
-}
+E_CONTACT_DEFINE_BOXED_TYPE (e_contact_cert, "EContactCert")
