@@ -43,6 +43,8 @@
 
 #include "libedataserver/e-source-list.h"
 
+G_DEFINE_TYPE (ECalBackendContacts, e_cal_backend_contacts, E_TYPE_CAL_BACKEND_SYNC)
+
 static ECalBackendSyncClass *parent_class;
 
 typedef enum
@@ -79,12 +81,14 @@ struct _ECalBackendContactsPrivate {
 };
 
 typedef struct _BookRecord {
+	ECalBackendContacts *cbc;
         EBook     *book;
         EBookView *book_view;
 } BookRecord;
 
 typedef struct _ContactRecord {
         ECalBackendContacts *cbc;
+	EBook               *book; /* where it comes from */
         EContact            *contact;
         ECalComponent       *comp_birthday, *comp_anniversary;
 } ContactRecord;
@@ -146,18 +150,29 @@ book_record_new (ECalBackendContacts *cbc, ESource *source)
         e_book_view_start (book_view);
 
         br = g_new (BookRecord, 1);
+	br->cbc = cbc;
         br->book = book;
         br->book_view = book_view;
 
         return br;
 }
 
+static gboolean
+remove_by_book (gpointer key, gpointer value, gpointer user_data)
+{
+	ContactRecord *cr = value;
+	EBook *book = user_data;
+
+	return (cr && cr->book == book);
+}
+
 static void
 book_record_free (BookRecord *br)
 {
         if (!br)
                 return;
 
+	g_hash_table_foreach_remove (br->cbc->priv->tracked_contacts, remove_by_book, br->book);
         g_object_unref (br->book_view);
         g_object_unref (br->book);
 
@@ -166,12 +181,13 @@ book_record_free (BookRecord *br)
 
 /* ContactRecord methods */
 static ContactRecord *
-contact_record_new (ECalBackendContacts *cbc, EContact *contact)
+contact_record_new (ECalBackendContacts *cbc, EBook *book, EContact *contact)
 {
         ContactRecord *cr = g_new0 (ContactRecord, 1);
 	gchar *comp_str;
 
         cr->cbc = cbc;
+	cr->book = book;
         cr->contact = contact;
         cr->comp_birthday = create_birthday (cbc, contact);
         cr->comp_anniversary = create_anniversary (cbc, contact);
@@ -275,6 +291,22 @@ contact_record_cb (gpointer key, gpointer value, gpointer user_data)
         }
 }
 
+static gboolean
+is_source_usable (ESource *source, ESourceGroup *group)
+{
+	const gchar *base_uri;
+	const gchar *prop;
+
+        base_uri = e_source_group_peek_base_uri (group);
+        if (!base_uri)
+                return FALSE;
+
+	prop = e_source_get_property (source, "use-in-contacts-calendar");
+
+	/* the later check is for backward compatibility */
+	return (prop && g_str_equal (prop, "1")) || (!prop && g_str_has_prefix (base_uri, "file://"));
+}
+
 /* SourceList callbacks */
 static void
 add_source (ECalBackendContacts *cbc, ESource *source)
@@ -295,7 +327,8 @@ source_added_cb (ESourceGroup *group, ESource *source, gpointer user_data)
 
         g_return_if_fail (cbc);
 
-        add_source (cbc, source);
+	if (is_source_usable (source, group))
+		add_source (cbc, source);
 }
 
 static void
@@ -309,30 +342,57 @@ source_removed_cb (ESourceGroup *group, ESource *source, gpointer user_data)
         g_hash_table_remove (cbc->priv->addressbooks, uid);
 }
 
+static void
+source_list_changed_cb (ESourceList *source_list, gpointer user_data)
+{
+        ECalBackendContacts *cbc = E_CAL_BACKEND_CONTACTS (user_data);
+        GSList *g, *s;
+
+        g_return_if_fail (cbc);
+
+	for (g = e_source_list_peek_groups (source_list); g; g = g->next) {
+		ESourceGroup *group = E_SOURCE_GROUP (g->data);
+
+		if (!group)
+			continue;
+
+		for (s = e_source_group_peek_sources (group); s; s = s->next) {
+			ESource *source = E_SOURCE (s->data);
+			const gchar *uid;
+
+			if (!source)
+				continue;
+
+			uid = e_source_peek_uid (source);
+			if (!uid)
+				continue;
+
+			if (is_source_usable (source, group)) {
+				if (!g_hash_table_lookup (cbc->priv->addressbooks, uid))
+					source_added_cb (group, source, cbc);
+			} else if (g_hash_table_lookup (cbc->priv->addressbooks, uid)) {
+				source_removed_cb (group, source, cbc);
+			}
+		}
+	}
+}
+
 static void
 source_group_added_cb (ESourceList *source_list, ESourceGroup *group, gpointer user_data)
 {
         ECalBackendContacts *cbc = E_CAL_BACKEND_CONTACTS (user_data);
-        const gchar *base_uri;
         GSList *i;
 
         g_return_if_fail (cbc);
 
-        base_uri = e_source_group_peek_base_uri (group);
-        if (!base_uri)
-                return;
-
-        /* Load all address books from this group */
-	if (!strncmp (base_uri, "file", 4)) {
-		for (i = e_source_group_peek_sources (group); i; i = i->next) {
-			ESource *source = E_SOURCE (i->data);
-			add_source (cbc, source);
-		}
-
-		/* Watch for future changes */
-		g_signal_connect (group, "source_added", G_CALLBACK (source_added_cb), cbc);
-		g_signal_connect (group, "source_removed", G_CALLBACK (source_removed_cb), cbc);
+	for (i = e_source_group_peek_sources (group); i; i = i->next) {
+		ESource *source = E_SOURCE (i->data);
+		source_added_cb (group, source, cbc);
 	}
+
+	/* Watch for future changes */
+	g_signal_connect (group, "source_added", G_CALLBACK (source_added_cb), cbc);
+	g_signal_connect (group, "source_removed", G_CALLBACK (source_removed_cb), cbc);
 }
 
 static void
@@ -358,22 +418,29 @@ static void
 contacts_changed_cb (EBookView *book_view, const GList *contacts, gpointer user_data)
 {
         ECalBackendContacts *cbc = E_CAL_BACKEND_CONTACTS (user_data);
+	EBook *book = e_book_view_get_book (book_view);
         const GList *i;
 
         for (i = contacts; i; i = i->next) {
                 EContact *contact = E_CONTACT (i->data);
                 const gchar *uid = e_contact_get_const (contact, E_CONTACT_UID);
+                EContactDate *birthday, *anniversary;
 
                 /* Because this is a change of contact, then always remove old tracked data
 		   and if possible, add with (possibly) new values.
 		*/
 		g_hash_table_remove (cbc->priv->tracked_contacts, (gchar *)uid);
 
-                if (e_contact_get (contact, E_CONTACT_BIRTH_DATE) ||
-                    e_contact_get (contact, E_CONTACT_ANNIVERSARY)) {
-                        ContactRecord *cr = contact_record_new (cbc, contact);
+                birthday = e_contact_get (contact, E_CONTACT_BIRTH_DATE);
+                anniversary = e_contact_get (contact, E_CONTACT_ANNIVERSARY);
+
+                if (birthday || anniversary) {
+                        ContactRecord *cr = contact_record_new (cbc, book, contact);
                         g_hash_table_insert (cbc->priv->tracked_contacts, g_strdup (uid), cr);
                 }
+
+                e_contact_date_free (birthday);
+                e_contact_date_free (anniversary);
         }
 }
 
@@ -381,6 +448,7 @@ static void
 contacts_added_cb (EBookView *book_view, const GList *contacts, gpointer user_data)
 {
         ECalBackendContacts *cbc = E_CAL_BACKEND_CONTACTS (user_data);
+	EBook *book = e_book_view_get_book (book_view);
         const GList *i;
 
         /* See if any new contacts have BIRTHDAY or ANNIVERSARY fields */
@@ -393,7 +461,7 @@ contacts_added_cb (EBookView *book_view, const GList *contacts, gpointer user_da
                 anniversary = e_contact_get (contact, E_CONTACT_ANNIVERSARY);
 
                 if (birthday || anniversary) {
-                        ContactRecord *cr = contact_record_new (cbc, contact);
+                        ContactRecord *cr = contact_record_new (cbc, book, contact);
                         const gchar    *uid = e_contact_get_const (contact, E_CONTACT_UID);
 
                         g_hash_table_insert (cbc->priv->tracked_contacts, g_strdup (uid), cr);
@@ -916,7 +984,7 @@ init_sources_cb (ECalBackendContacts *cbc)
         ECalBackendContactsPrivate *priv;
         GSList *i;
 
-	g_return_val_if_fail (cbc != NULL, FALSE);
+	g_return_val_if_fail (cbc != NULL, NULL);
 
 	priv = cbc->priv;
 
@@ -928,6 +996,7 @@ init_sources_cb (ECalBackendContacts *cbc)
         }
 
         /* Listen for source list changes */
+        g_signal_connect (priv->addressbook_sources, "changed", G_CALLBACK (source_list_changed_cb), cbc);
         g_signal_connect (priv->addressbook_sources, "group_added", G_CALLBACK (source_group_added_cb), cbc);
         g_signal_connect (priv->addressbook_sources, "group_removed", G_CALLBACK (source_group_removed_cb), cbc);
 
@@ -981,32 +1050,6 @@ e_cal_backend_contacts_is_loaded (ECalBackend *backend)
         return priv->addressbook_loaded;
 }
 
-static ECalBackendSyncStatus
-e_cal_backend_contacts_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
-{
-	ECalBackendContacts *cbcontacts;
-	ECalBackendContactsPrivate *priv;
-	icaltimezone *zone;
-	icalcomponent *icalcomp;
-
-	cbcontacts = E_CAL_BACKEND_CONTACTS (backend);
-	priv = cbcontacts->priv;
-
-	g_return_val_if_fail (tzid != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
-
-	zone = e_cal_backend_internal_get_timezone (E_CAL_BACKEND (backend), tzid);
-	if (!zone)
-		return GNOME_Evolution_Calendar_ObjectNotFound;
-
-	icalcomp = icaltimezone_get_component (zone);
-	if (!icalcomp)
-		return GNOME_Evolution_Calendar_InvalidObject;
-
-	*object = icalcomponent_as_ical_string_r (icalcomp);
-
-	return GNOME_Evolution_Calendar_Success;
-}
-
 /* Add_timezone handler for the file backend */
 static ECalBackendSyncStatus
 e_cal_backend_contacts_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
@@ -1200,7 +1243,7 @@ e_cal_backend_contacts_finalize (GObject *object)
 
 /* Object initialization function for the contacts backend */
 static void
-e_cal_backend_contacts_init (ECalBackendContacts *cbc, ECalBackendContactsClass *class)
+e_cal_backend_contacts_init (ECalBackendContacts *cbc)
 {
 	ECalBackendContactsPrivate *priv;
 
@@ -1272,7 +1315,6 @@ e_cal_backend_contacts_class_init (ECalBackendContactsClass *class)
 	sync_class->get_default_object_sync = e_cal_backend_contacts_get_default_object;
 	sync_class->get_object_sync = e_cal_backend_contacts_get_object;
 	sync_class->get_object_list_sync = e_cal_backend_contacts_get_object_list;
-	sync_class->get_timezone_sync = e_cal_backend_contacts_get_timezone;
 	sync_class->add_timezone_sync = e_cal_backend_contacts_add_timezone;
 	sync_class->set_default_zone_sync = e_cal_backend_contacts_set_default_zone;
 	sync_class->get_freebusy_sync = e_cal_backend_contacts_get_free_busy;
@@ -1285,35 +1327,3 @@ e_cal_backend_contacts_class_init (ECalBackendContactsClass *class)
 	backend_class->internal_get_default_timezone = e_cal_backend_contacts_internal_get_default_timezone;
 	backend_class->internal_get_timezone = e_cal_backend_contacts_internal_get_timezone;
 }
-
-/**
- * e_cal_backend_contacts_get_type:
- * @void:
- *
- * Registers the #ECalBackendContacts class if necessary, and returns
- * the type ID associated to it.
- *
- * Return value: The type ID of the #ECalBackendContacts class.
- **/
-GType
-e_cal_backend_contacts_get_type (void)
-{
-	static GType e_cal_backend_contacts_type = 0;
-
-	if (!e_cal_backend_contacts_type) {
-		static GTypeInfo info = {
-                        sizeof (ECalBackendContactsClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) e_cal_backend_contacts_class_init,
-                        NULL, NULL,
-                        sizeof (ECalBackendContacts),
-                        0,
-                        (GInstanceInitFunc) e_cal_backend_contacts_init
-                };
-		e_cal_backend_contacts_type = g_type_register_static (E_TYPE_CAL_BACKEND_SYNC,
-                                                                     "ECalBackendContacts", &info, 0);
-	}
-
-	return e_cal_backend_contacts_type;
-}
