@@ -62,7 +62,11 @@ GHashTable* e_cal_backend_groupwise_get_categories_by_id (ECalBackendGroupwise *
 GHashTable* e_cal_backend_groupwise_get_categories_by_name (ECalBackendGroupwise *cbgw);
 icaltimezone* e_cal_backend_groupwise_get_default_zone (ECalBackendGroupwise *cbgw);
 void    e_cal_backend_groupwise_notify_error_code (ECalBackendGroupwise *cbgw, EGwConnectionStatus status);
+const gchar *e_cal_backend_groupwise_get_container_id (ECalBackendGroupwise *cbgw);
 const gchar * e_cal_backend_groupwise_get_local_attachments_store (ECalBackendGroupwise *cbgw);
+void e_cal_backend_groupwise_priv_lock (ECalBackendGroupwise *cbgw);
+void e_cal_backend_groupwise_priv_unlock (ECalBackendGroupwise *cbgw);
+
 G_END_DECLS
 
 #endif
