@@ -163,6 +163,16 @@ e_data_cal_new (ECalBackend *backend, ESource *source)
 	return cal;
 }
 
+/**
+ * e_data_cal_get_source:
+ * @cal: an #EDataCal
+ *
+ * Returns the #ESource for @cal.
+ *
+ * Returns: the #ESource for @cal
+ *
+ * Since: 2.30
+ **/
 ESource*
 e_data_cal_get_source (EDataCal *cal)
 {
@@ -570,6 +580,8 @@ e_data_cal_notify_open (EDataCal *cal, EServerMethodContext context, EDataCalCal
  * @status: Status code.
  *
  * Notifies listeners of the completion of the refresh method call.
+ *
+ * Since: 2.30
  */
 void
 e_data_cal_notify_refresh (EDataCal *cal, EServerMethodContext context, EDataCalCallStatus status)
@@ -634,7 +646,7 @@ e_data_cal_notify_object_modified (EDataCal *cal, EServerMethodContext context,
 {
 	DBusGMethodInvocation *method = context;
 	if (status != Success) {
-		dbus_g_method_return_error (method, g_error_new (E_DATA_CAL_ERROR, status, _("Cannot modify calender object")));
+		dbus_g_method_return_error (method, g_error_new (E_DATA_CAL_ERROR, status, _("Cannot modify calendar object")));
 	} else {
 		e_cal_backend_notify_object_modified (cal->priv->backend, old_object, object);
 		dbus_g_method_return (method);
@@ -974,7 +986,7 @@ e_data_cal_notify_free_busy (EDataCal *cal, EServerMethodContext context, EDataC
 		GList *l;
 		gint i;
 
-		seq = g_new0 (gchar *, g_list_length (freebusy));
+		seq = g_new0 (gchar *, g_list_length (freebusy) + 1);
 		for (i = 0, l = freebusy; l; i++, l = l->next) {
 			seq[i] = g_strdup (l->data);
 		}
