@@ -40,8 +40,6 @@
 #define EWOULDBLOCK EAGAIN
 #endif
 
-#include <libedataserver/e-data-server-util.h>
-
 #include "camel-file-utils.h"
 #include "camel-operation.h"
 #include "camel-url.h"
@@ -55,7 +53,7 @@
  *
  * Utility function to save an uint32 to a file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_uint32 (FILE *out, guint32 value)
@@ -79,7 +77,7 @@ camel_file_util_encode_uint32 (FILE *out, guint32 value)
  *
  * Retrieve an encoded uint32 from a file.
  *
- * Return value: %0 on success, %-1 on error.  @*dest will contain the
+ * Returns: %0 on success, %-1 on error.  @*dest will contain the
  * decoded value.
  **/
 gint
@@ -110,7 +108,7 @@ camel_file_util_decode_uint32 (FILE *in, guint32 *dest)
  * Encode a gint32, performing no compression, but converting
  * to network order.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
@@ -130,7 +128,7 @@ camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
  *
  * Retrieve a gint32.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_fixed_int32 (FILE *in, gint32 *dest)
@@ -183,7 +181,7 @@ camel_file_util_decode_##type(FILE *in, type *dest)	\
  *
  * Encode a time_t value to the file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(time_t)
 
@@ -194,7 +192,7 @@ CFU_ENCODE_T(time_t)
  *
  * Decode a time_t value.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_DECODE_T(time_t)
 
@@ -205,7 +203,7 @@ CFU_DECODE_T(time_t)
  *
  * Encode an off_t type.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(off_t)
 
@@ -216,7 +214,7 @@ CFU_ENCODE_T(off_t)
  *
  * Decode an off_t type.
  *
- * Return value: %0 on success, %-1 on failure.
+ * Returns: %0 on success, %-1 on failure.
  **/
 CFU_DECODE_T(off_t)
 
@@ -227,7 +225,7 @@ CFU_DECODE_T(off_t)
  *
  * Encode an gsize type.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(gsize)
 
@@ -238,7 +236,7 @@ CFU_ENCODE_T(gsize)
  *
  * Decode an gsize type.
  *
- * Return value: %0 on success, %-1 on failure.
+ * Returns: %0 on success, %-1 on failure.
  **/
 CFU_DECODE_T(gsize)
 
@@ -249,7 +247,7 @@ CFU_DECODE_T(gsize)
  *
  * Encode a normal string and save it in the output file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_string (FILE *out, const gchar *str)
@@ -276,7 +274,7 @@ camel_file_util_encode_string (FILE *out, const gchar *str)
  *
  * Decode a normal string from the input file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_string (FILE *in, gchar **str)
@@ -317,7 +315,7 @@ camel_file_util_decode_string (FILE *in, gchar **str)
  * Unlike @camel_file_util_encode_string, it pads the
  * @str with "NULL" bytes, if @len is > strlen(str)
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
@@ -349,7 +347,7 @@ camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
  *
  * Decode a normal string from the input file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_fixed_string (FILE *in, gchar **str, gsize len)
@@ -622,7 +620,7 @@ camel_read_socket (gint fd, gchar *buf, gsize n)
 			if (res == -1)
 				;
 			else if (res == 0)
-				errno = ETIMEDOUT;
+				errno = EAGAIN;
 			else if (FD_ISSET (cancel_fd, &rdset)) {
 				errno = EINTR;
 				goto failed;
@@ -697,7 +695,7 @@ camel_write_socket (gint fd, const gchar *buf, gsize n)
 			if (res == SOCKET_ERROR) {
 				/* w still being -1 will catch this */
 			} else if (res == 0)
-				errno = ETIMEDOUT;
+				errno = EAGAIN;
 			else if (FD_ISSET (cancel_fd, &rdset))
 				errno = EINTR;
 			else {
@@ -728,7 +726,7 @@ camel_write_socket (gint fd, const gchar *buf, gsize n)
  * basename of @filename, for instance used in a two-stage commit file
  * write.
  *
- * Return value: The new pathname.  It must be free'd with g_free().
+ * Returns: The new pathname.  It must be free'd with g_free().
  **/
 gchar *
 camel_file_util_savename(const gchar *filename)
@@ -752,3 +750,22 @@ camel_file_util_savename(const gchar *filename)
 
 	return retval;
 }
+
+/**
+ * camel_mkdir:
+ * @path: directory path to create
+ * @mode: permissions
+ *
+ * Creates the directory path described in @path, creating any parent
+ * directories as necessary.
+ *
+ * Returns 0 on success or -1 on fail. In the case of failure, errno
+ * will be set appropriately.
+ *
+ * Since: 2.30
+ **/
+gint
+camel_mkdir (const gchar *path, mode_t mode)
+{
+	return g_mkdir_with_parents (path, mode);
+}
