@@ -224,7 +224,7 @@ camel_folder_search_construct (CamelFolderSearch *search)
 	gint i;
 	CamelFolderSearchClass *klass = (CamelFolderSearchClass *)CAMEL_OBJECT_GET_CLASS(search);
 
-	for (i=0;i<sizeof(builtins)/sizeof(builtins[0]);i++) {
+	for (i = 0; i < G_N_ELEMENTS (builtins); i++) {
 		gpointer func;
 		/* c is sure messy sometimes */
 		func = *((gpointer *)(((gchar *)klass)+builtins[i].offset));
@@ -252,7 +252,7 @@ camel_folder_search_construct (CamelFolderSearch *search)
  * Particular methods may be overriden by an implementation to
  * implement a search for any sort of backend.
  *
- * Return value: A new CamelFolderSearch widget.
+ * Returns: A new CamelFolderSearch widget.
  **/
 CamelFolderSearch *
 camel_folder_search_new (void)
@@ -329,7 +329,7 @@ camel_folder_search_set_body_index(CamelFolderSearch *search, CamelIndex *index)
  * TODO: The interface should probably return summary items instead
  * (since they are much more useful to any client).
  *
- * Return value: A GPtrArray of strings of all matching messages.
+ * Returns: A GPtrArray of strings of all matching messages.
  * This must only be freed by camel_folder_search_free_result.
  **/
 GPtrArray *
@@ -418,7 +418,9 @@ camel_folder_search_execute_expression(CamelFolderSearch *search, const gchar *e
  * Run a search.  Search must have had Folder already set on it, and
  * it must implement summaries.
  *
- * Return value: Number of messages that match the query.
+ * Returns: Number of messages that match the query.
+ *
+ * Since: 2.26
  **/
 
 guint32
@@ -563,7 +565,7 @@ do_search_in_memory (const gchar *expr)
  * Run a search.  Search must have had Folder already set on it, and
  * it must implement summaries.
  *
- * Return value:
+ * Returns:
  **/
 GPtrArray *
 camel_folder_search_search(CamelFolderSearch *search, const gchar *expr, GPtrArray *uids, CamelException *ex)
@@ -769,7 +771,7 @@ search_not(struct _ESExp *f, gint argc, struct _ESExpResult **argv, CamelFolderS
 			gint res = TRUE;
 
 			if (argv[0]->type == ESEXP_RES_BOOL)
-				res = ! argv[0]->value.bool;
+				res = !argv[0]->value.bool;
 
 			r = e_sexp_result_new(f, ESEXP_RES_BOOL);
 			r->value.bool = res;
@@ -834,7 +836,6 @@ search_match_all(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, CamelFol
 		camel_folder_summary_reload_from_db (search->folder->summary, search->priv->ex);
 	}
 
-
 	for (i=0;i<v->len;i++) {
 		const gchar *uid;
 
