@@ -238,7 +238,7 @@ text_index_add_name_to_word(CamelIndex *idx, const gchar *word, camel_key_t name
 		camel_dlist_addhead(&p->word_cache, (CamelDListNode *)w);
 		w->names[w->used] = nameid;
 		w->used++;
-		if (w->used == sizeof(w->names)/sizeof(w->names[0])) {
+		if (w->used == G_N_ELEMENTS (w->names)) {
 			io(printf("writing key file entry '%s' [%x]\n", w->word, w->data));
 			if (camel_key_file_write(p->links, &w->data, w->used, w->names) != -1) {
 				rb->keys++;
@@ -280,7 +280,7 @@ text_index_sync(CamelIndex *idx)
 
 	work = !camel_dlist_empty(&p->word_cache);
 
-	while ( (ww = (struct _CamelTextIndexWord *)camel_dlist_remhead(&p->word_cache)) ) {
+	while ((ww = (struct _CamelTextIndexWord *)camel_dlist_remhead(&p->word_cache))) {
 		if (ww->used > 0) {
 			io(printf("writing key file entry '%s' [%x]\n", ww->word, ww->data));
 			if (camel_key_file_write(p->links, &ww->data, ww->used, ww->names) != -1) {
@@ -415,7 +415,7 @@ text_index_compress_nosync(CamelIndex *idx)
 	remap = g_hash_table_new(NULL, NULL);
 	oldkeyid = 0;
 	deleted = 0;
-	while ( (oldkeyid = camel_key_table_next(oldp->name_index, oldkeyid, &name, &flags, &data)) ) {
+	while ((oldkeyid = camel_key_table_next(oldp->name_index, oldkeyid, &name, &flags, &data))) {
 		if ((flags&1) == 0) {
 			io(printf("copying name '%s'\n", name));
 			newkeyid = camel_key_table_add(newp->name_index, name, data, flags);
@@ -436,7 +436,7 @@ text_index_compress_nosync(CamelIndex *idx)
 	/* We re-block the data into 256 entry lots while we're at it, since we only
 	   have to do 1 at a time and its cheap */
 	oldkeyid = 0;
-	while ( (oldkeyid = camel_key_table_next(oldp->word_index, oldkeyid, &name, &flags, &data)) ) {
+	while ((oldkeyid = camel_key_table_next(oldp->word_index, oldkeyid, &name, &flags, &data))) {
 		io(printf("copying word '%s'\n", name));
 		newdata = 0;
 		newcount = 0;
@@ -453,7 +453,7 @@ text_index_compress_nosync(CamelIndex *idx)
 				newkeyid = (camel_key_t)GPOINTER_TO_INT(g_hash_table_lookup(remap, GINT_TO_POINTER(records[i])));
 				if (newkeyid) {
 					newrecords[newcount++] = newkeyid;
-					if (newcount == sizeof(newrecords)/sizeof(newrecords[0])) {
+					if (newcount == G_N_ELEMENTS (newrecords)) {
 						if (camel_key_file_write(newp->links, &newdata, newcount, newrecords) == -1) {
 							g_free(records);
 							goto fail;
@@ -1056,7 +1056,7 @@ add_partition(GHashTable *map, CamelBlockFile *blocks, camel_block_t id)
 		}
 
 		pm = (CamelPartitionMapBlock *)&bl->data;
-		if (pm->used > sizeof(pm->partition)/sizeof(pm->partition[0])) {
+		if (pm->used > G_N_ELEMENTS (pm->partition)) {
 			g_warning("Partition block %x invalid\n", id);
 			camel_block_file_unref_block(blocks, bl);
 			return;
@@ -1210,7 +1210,7 @@ camel_text_index_dump(CamelTextIndex *idx)
 	printf("UID's in index\n");
 
 	keyid = 0;
-	while ( (keyid = camel_key_table_next(p->name_index, keyid, &word, &flags, &data)) ) {
+	while ((keyid = camel_key_table_next(p->name_index, keyid, &word, &flags, &data))) {
 		if ((flags & 1) == 0)
 			printf(" %s\n", word);
 		else
@@ -1221,13 +1221,13 @@ camel_text_index_dump(CamelTextIndex *idx)
 	printf("Word's in index\n");
 
 	keyid = 0;
-	while ( (keyid = camel_key_table_next(p->word_index, keyid, &word, &flags, &data)) ) {
+	while ((keyid = camel_key_table_next(p->word_index, keyid, &word, &flags, &data))) {
 		CamelIndexCursor *idc;
 
 		printf("Word: '%s':\n", word);
 
 		idc = camel_index_find((CamelIndex *)idx, word);
-		while ( (name = camel_index_cursor_next(idc)) ) {
+		while ((name = camel_index_cursor_next(idc))) {
 			printf(" %s", name);
 		}
 		printf("\n");
@@ -1283,7 +1283,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 	printf("Checking UID consistency\n");
 
 	keyid = 0;
-	while ( (keyid = camel_key_table_next(p->name_index, keyid, &word, &flags, &data)) ) {
+	while ((keyid = camel_key_table_next(p->name_index, keyid, &word, &flags, &data))) {
 		if ((oldword = g_hash_table_lookup(names, GINT_TO_POINTER(keyid))) != NULL
 		    || (oldword = g_hash_table_lookup(deleted, GINT_TO_POINTER(keyid))) != NULL) {
 			printf("Warning, name '%s' duplicates key (%x) with name '%s'\n", word, keyid, oldword);
@@ -1301,7 +1301,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 	printf("Checking WORD member consistency\n");
 
 	keyid = 0;
-	while ( (keyid = camel_key_table_next(p->word_index, keyid, &word, &flags, &data)) ) {
+	while ((keyid = camel_key_table_next(p->word_index, keyid, &word, &flags, &data))) {
 		CamelIndexCursor *idc;
 		GHashTable *used;
 
@@ -1335,7 +1335,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 		used = g_hash_table_new(g_str_hash, g_str_equal);
 
 		idc = camel_index_find((CamelIndex *)idx, word);
-		while ( (name = camel_index_cursor_next(idc)) ) {
+		while ((name = camel_index_cursor_next(idc))) {
 			if (g_hash_table_lookup(name_word, name) == NULL) {
 				printf("word '%s' references non-existant name '%s'\n", word, name);
 			}
@@ -1412,7 +1412,7 @@ camel_utf8_next(const guchar **ptr, const guchar *ptrend)
 	if (p == ptrend)
 		return 0;
 
-	while ( (c = *p++) ) {
+	while ((c = *p++)) {
 		if (c < 0x80) {
 			*ptr = p;
 			return c;
@@ -1705,7 +1705,7 @@ text_index_key_cursor_next(CamelIndexCursor *idc)
 	g_free(p->current);
 	p->current = NULL;
 
-	while ( (p->keyid = camel_key_table_next(p->table, p->keyid, &p->current, &p->flags, &p->data)) ) {
+	while ((p->keyid = camel_key_table_next(p->table, p->keyid, &p->current, &p->flags, &p->data))) {
 		if ((p->flags & 1) == 0) {
 			return p->current;
 		} else {
@@ -1862,7 +1862,7 @@ gint main(gint argc, gchar **argv)
 
 	printf("Looking up which names contain word 'word'\n");
 	idc = camel_index_find(idx, "words");
-	while ( (word = camel_index_cursor_next(idc)) != NULL ) {
+	while ((word = camel_index_cursor_next(idc)) != NULL) {
 		printf(" name is '%s'\n", word);
 	}
 	camel_object_unref((CamelObject *)idc);
@@ -1870,7 +1870,7 @@ gint main(gint argc, gchar **argv)
 
 	printf("Looking up which names contain word 'truncate'\n");
 	idc = camel_index_find(idx, "truncate");
-	while ( (word = camel_index_cursor_next(idc)) != NULL ) {
+	while ((word = camel_index_cursor_next(idc)) != NULL) {
 		printf(" name is '%s'\n", word);
 	}
 	camel_object_unref((CamelObject *)idc);
