@@ -21,7 +21,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,6 +32,7 @@
 #include <prthread.h>
 #include "nss.h"      /* Don't use <> here or it will include the system nss.h instead */
 #include <ssl.h>
+#include <errno.h>
 #endif /* HAVE_NSS */
 
 #include <glib.h>
@@ -56,20 +56,44 @@ PRLock *nss_initlock = NULL;
 volatile gboolean nss_initialized = FALSE;
 #endif
 
-static int initialised = FALSE;
+static gint initialised = FALSE;
 
-int camel_application_is_exiting = FALSE;
+gint camel_application_is_exiting = FALSE;
 
-int
-camel_init (const char *configdir, gboolean nss_init)
+#define NSS_SYSTEM_DB "/etc/pki/nssdb"
+
+static gint
+nss_has_system_db(void)
+{
+	gint found = FALSE;
+#ifndef G_OS_WIN32
+	FILE *f;
+	gchar buf[80];
+
+	f = fopen(NSS_SYSTEM_DB "/pkcs11.txt", "r");
+	if (!f)
+		return FALSE;
+
+	/* Check whether the system NSS db is actually enabled */
+	while (fgets(buf, 80, f) && !found) {
+		if (!strcmp(buf, "library=libnsssysinit.so\n"))
+			found = TRUE;
+	}
+	fclose(f);
+#endif
+	return found;
+}
+
+gint
+camel_init (const gchar *configdir, gboolean nss_init)
 {
 	CamelCertDB *certdb;
-	char *path;
-	
+	gchar *path;
+
 	if (initialised)
 		return 0;
 
-	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	camel_debug_init();
@@ -79,7 +103,9 @@ camel_init (const char *configdir, gboolean nss_init)
 
 #ifdef HAVE_NSS
 	if (nss_init) {
-		char *nss_configdir;
+		gchar *nss_configdir = NULL;
+		gchar *nss_sql_configdir = NULL;
+		SECStatus status = SECFailure;
 		PRUint16 indx;
 
 		if (nss_initlock == NULL) {
@@ -87,28 +113,79 @@ camel_init (const char *configdir, gboolean nss_init)
 			nss_initlock = PR_NewLock();
 		}
 		PR_Lock (nss_initlock);
-		
+
+		if (NSS_IsInitialized ())
+			goto skip_nss_init;
+
 #ifndef G_OS_WIN32
 		nss_configdir = g_strdup (configdir);
 #else
 		nss_configdir = g_win32_locale_filename_from_utf8 (configdir);
 #endif
 
-		if (!NSS_IsInitialized()) {
-			nss_initialized = 1;
+		if (nss_has_system_db ()) {
+			nss_sql_configdir = g_strdup ("sql:" NSS_SYSTEM_DB );
+		} else {
+			/* On Windows, we use the Evolution configdir. On other
+			 * operating systems we use ~/.pki/nssdb/, which is where
+			 * the user-specific part of the "shared system db" is
+			 * stored and is what Chrome uses too.
+			 *
+			 * We have to create the configdir if it does not exist,
+			 * to prevent camel from bailing out on first run. */
+#ifdef G_OS_WIN32
+			g_mkdir_with_parents (configdir, 0700);
+			nss_sql_configdir = g_strconcat ("sql:", nss_configdir, NULL);
+#else
+			gchar *user_nss_dir = g_build_filename ( g_get_home_dir (),
+								 ".pki/nssdb", NULL );
+			if (g_mkdir_with_parents (user_nss_dir, 0700))
+				g_warning("Failed to create SQL database directory %s: %s\n",
+					  user_nss_dir, strerror(errno));
 
-			if (NSS_InitReadWrite (nss_configdir) == SECFailure) {
-				/* fall back on using volatile dbs? */
-				if (NSS_NoDB_Init (nss_configdir) == SECFailure) {
-					g_free (nss_configdir);
-					g_warning ("Failed to initialize NSS");
-					nss_initialized = 0;
-					PR_Unlock(nss_initlock);
-					return -1;
-				}
+			nss_sql_configdir = g_strconcat ("sql:", user_nss_dir, NULL);
+			g_free(user_nss_dir);
+#endif
+		}
+
+#if NSS_VMAJOR > 3 || (NSS_VMAJOR == 3 && NSS_VMINOR >= 12)
+		/* See: https://wiki.mozilla.org/NSS_Shared_DB,
+		 * particularly "Mode 3A".  Note that the target
+		 * directory MUST EXIST. */
+		status = NSS_InitWithMerge (
+			nss_sql_configdir,	/* dest dir */
+			"", "",			/* new DB name prefixes */
+			SECMOD_DB,		/* secmod name */
+			nss_configdir,		/* old DB dir */
+			"", "",			/* old DB name prefixes */
+			nss_configdir,		/* unique ID for old DB */
+			"Evolution S/MIME",	/* UI name for old DB */
+			0);			/* flags */
+
+		if (status == SECFailure) {
+			g_warning ("Failed to initialize NSS SQL database in %s: NSS error %d",
+				   nss_sql_configdir, PORT_GetError());
+			/* Fall back to opening the old DBM database */
+		}
+#endif
+		/* Support old versions of libnss, pre-sqlite support. */
+		if (status == SECFailure)
+			status = NSS_InitReadWrite (nss_configdir);
+		if (status == SECFailure) {
+			/* Fall back to using volatile dbs? */
+			status = NSS_NoDB_Init (nss_configdir);
+			if (status == SECFailure) {
+				g_free (nss_configdir);
+				g_free (nss_sql_configdir);
+				g_warning ("Failed to initialize NSS");
+				PR_Unlock (nss_initlock);
+				return -1;
 			}
 		}
 
+		nss_initialized = TRUE;
+skip_nss_init:
+
 		NSS_SetDomesticPolicy ();
 
 		PR_Unlock(nss_initlock);
@@ -117,35 +194,41 @@ camel_init (const char *configdir, gboolean nss_init)
 		for (indx = 0; indx < SSL_NumImplementedCiphers; indx++) {
 			if (!SSL_IS_SSL2_CIPHER(SSL_ImplementedCiphers[indx]))
 				SSL_CipherPrefSetDefault (SSL_ImplementedCiphers[indx], PR_TRUE);
-		}	
-		
+		}
+
 		SSL_OptionSetDefault (SSL_ENABLE_SSL2, PR_TRUE);
 		SSL_OptionSetDefault (SSL_ENABLE_SSL3, PR_TRUE);
 		SSL_OptionSetDefault (SSL_ENABLE_TLS, PR_TRUE);
 		SSL_OptionSetDefault (SSL_V2_COMPATIBLE_HELLO, PR_TRUE /* maybe? */);
 
 		g_free (nss_configdir);
+		g_free (nss_sql_configdir);
 	}
 #endif /* HAVE_NSS */
-	
+
 	path = g_strdup_printf ("%s/camel-cert.db", configdir);
 	certdb = camel_certdb_new ();
 	camel_certdb_set_filename (certdb, path);
 	g_free (path);
-	
+
 	/* if we fail to load, who cares? it'll just be a volatile certdb */
 	camel_certdb_load (certdb);
-	
+
 	/* set this certdb as the default db */
 	camel_certdb_set_default (certdb);
-	
+
 	camel_object_unref (certdb);
-	
+
 	initialised = TRUE;
-	
+
 	return 0;
 }
 
+/**
+ * camel_shutdown:
+ *
+ * Since: 2.24
+ **/
 void
 camel_shutdown (void)
 {
@@ -163,10 +246,12 @@ camel_shutdown (void)
 	/* These next calls must come last. */
 
 #if defined (HAVE_NSS)
-	PR_Lock(nss_initlock);
-	if (nss_initialized)
-		NSS_Shutdown ();
-	PR_Unlock(nss_initlock);
+	if (nss_initlock != NULL) {
+		PR_Lock(nss_initlock);
+		if (nss_initialized)
+			NSS_Shutdown ();
+		PR_Unlock(nss_initlock);
+	}
 #endif /* HAVE_NSS */
 
 	initialised = FALSE;
