@@ -75,16 +75,16 @@ struct _CamelIMAPXServer {
 
 	/* info on currently selected folder */
 	struct _CamelFolder *select_folder;
-	gchar *select;
 	struct _CamelFolderChangeInfo *changes;
 	struct _CamelFolder *select_pending;
 	guint32 permanentflags;
-	guint32 uidvalidity;
 	guint32 unseen;
+	guint64 uidvalidity;
+	guint64 highestmodseq;
+	guint32 uidnext;
 	guint32 exists;
 	guint32 recent;
 	guint32 mode;
-	guint32 unread;
 
 	/* any expunges that happened from the last command, they are
 	   processed after the command completes. */
@@ -102,6 +102,8 @@ struct _CamelIMAPXServer {
 	struct _CamelIMAPXIdle *idle;
 	gboolean use_idle;
 
+	gboolean use_qresync;
+
 	/* used for storing eflags to syncronize duplicate get_message requests */
 	GHashTable *uid_eflags;
 };
@@ -115,10 +117,10 @@ struct _CamelIMAPXServerClass {
 CamelType               camel_imapx_server_get_type     (void);
 CamelIMAPXServer *camel_imapx_server_new(struct _CamelStore *store, struct _CamelURL *url);
 
-gboolean camel_imapx_server_connect(CamelIMAPXServer *is, gint state, CamelException *ex);
+gboolean camel_imapx_server_connect(CamelIMAPXServer *is, CamelException *ex);
 gboolean imapx_connect_to_server (CamelIMAPXServer *is, CamelException *ex);
 
-GPtrArray *camel_imapx_server_list(CamelIMAPXServer *is, const gchar *top, guint32 flags, CamelException *ex);
+GPtrArray *camel_imapx_server_list(CamelIMAPXServer *is, const gchar *top, guint32 flags, const gchar *ext, CamelException *ex);
 
 void camel_imapx_server_refresh_info(CamelIMAPXServer *is, CamelFolder *folder, struct _CamelException *ex);
 void camel_imapx_server_sync_changes(CamelIMAPXServer *is, CamelFolder *folder, CamelException *ex);
