@@ -124,6 +124,9 @@ imapx_parse_receiving_options (CamelIMAPXStore *istore, CamelURL *url)
 
 	if (camel_url_get_param (url, "use_idle"))
 		istore->rec_options |= IMAPX_USE_IDLE;
+
+	if (camel_url_get_param (url, "use_qresync"))
+		istore->rec_options |= IMAPX_USE_QRESYNC;
 }
 
 static void
@@ -204,16 +207,48 @@ imapx_get_name (CamelService *service, gboolean brief)
 					service->url->user, service->url->host);
 }
 
+CamelIMAPXServer *
+camel_imapx_store_get_server(CamelIMAPXStore *store, CamelException *ex)
+{
+	CamelIMAPXServer *server = NULL;
+
+	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
+
+	if (store->server && camel_imapx_server_connect(store->server, ex)) {
+		camel_object_ref(store->server);
+		server = store->server;
+	} else {
+		if (store->server) {
+			camel_object_unref(store->server);
+			store->server = NULL;
+		}
+
+		server = camel_imapx_server_new(CAMEL_STORE(store), CAMEL_SERVICE(store)->url);
+		if (camel_imapx_server_connect(server, ex)) {
+			store->server = server;
+			camel_object_ref(server);
+		} else {
+			camel_object_unref(server);
+			server = NULL;
+		}
+	}
+	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
+	return server;
+}
+
 static gboolean
 imapx_connect (CamelService *service, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *)service;
+	CamelIMAPXServer *server;
 
-	/* We never really are 'connected' or 'disconnected' */
-	if (istore->server == NULL)
-		istore->server = camel_imapx_server_new((CamelStore *)istore, service->url);
+	server = camel_imapx_store_get_server(istore, ex);
+	if (server) {
+		camel_object_unref(server);
+		return TRUE;
+	}
 
-	return camel_imapx_server_connect (istore->server, TRUE, ex);
+	return FALSE;
 }
 
 static gboolean
@@ -223,8 +258,14 @@ imapx_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 
 	CAMEL_SERVICE_CLASS (parent_class)->disconnect (service, clean, ex);
 
-	if (istore->server)
-		camel_imapx_server_connect(istore->server, FALSE, ex);
+	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
+
+	if (istore->server) {
+		camel_object_unref(istore->server);
+		istore->server = NULL;
+	}
+
+	CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 
 	return TRUE;
 }
@@ -267,12 +308,16 @@ static void
 imapx_noop (CamelStore *store, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 
 	if (CAMEL_OFFLINE_STORE(store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
 		return;
 
-	if (istore->server && camel_imapx_server_connect (istore->server, TRUE, ex))
-		camel_imapx_server_noop (istore->server, NULL, ex);
+	server = camel_imapx_store_get_server(istore, ex);
+	if (server) {
+		camel_imapx_server_noop (server, NULL, ex);
+		camel_object_unref(server);
+	}
 }
 
 static guint
@@ -528,12 +573,17 @@ static void
 imapx_subscribe_folder (CamelStore *store, const gchar *folder_name, gboolean emit_signal, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 
 	if (CAMEL_OFFLINE_STORE(store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
 		return;
 
-	if (istore->server && camel_imapx_server_connect (istore->server, TRUE, ex))
-		camel_imapx_server_manage_subscription (istore->server, folder_name, TRUE, ex);
+	server = camel_imapx_store_get_server(istore, ex);
+	if (!server)
+		return;
+
+	camel_imapx_server_manage_subscription (server, folder_name, TRUE, ex);
+	camel_object_unref(server);
 
 	if (!camel_exception_is_set (ex))
 		imapx_mark_folder_subscribed (istore, folder_name, emit_signal, ex);
@@ -543,12 +593,17 @@ static void
 imapx_unsubscribe_folder (CamelStore *store, const gchar *folder_name, gboolean emit_signal, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 
 	if (CAMEL_OFFLINE_STORE(store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
 		return;
 
-	if (istore->server && camel_imapx_server_connect (istore->server, TRUE, ex))
-		camel_imapx_server_manage_subscription (istore->server, folder_name, FALSE, ex);
+	server = camel_imapx_store_get_server(istore, ex);
+	if (!server)
+		return;
+
+	camel_imapx_server_manage_subscription (server, folder_name, FALSE, ex);
+	camel_object_unref(server);
 
 	if (!camel_exception_is_set (ex))
 		imapx_unmark_folder_subscribed (istore, folder_name, emit_signal, ex);
@@ -614,15 +669,19 @@ static void
 imapx_delete_folder (CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 
 	if (CAMEL_OFFLINE_STORE (store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 				     _("You must be working online to complete this operation"));
 		return;
 	}
+	server = camel_imapx_store_get_server(istore, ex);
+	if (!server)
+		return;
 
-	if (istore->server && camel_imapx_server_connect (istore->server, TRUE, ex))
-		camel_imapx_server_delete_folder (istore->server, folder_name, ex);
+	camel_imapx_server_delete_folder (server, folder_name, ex);
+	camel_object_unref(server);
 
 	if (!camel_exception_is_set (ex))
 		imapx_delete_folder_from_cache (istore, folder_name, ex);
@@ -650,12 +709,6 @@ rename_folder_info (CamelIMAPXStore *istore, const gchar *old_name, const gchar
 				npath = g_strdup(new_name);
 			nfull = camel_imapx_store_summary_path_to_full(istore->summary, npath, istore->dir_sep);
 
-			/* workaround for broken server (courier uses '.') that doesn't rename
-			   subordinate folders as required by rfc 2060 */
-			if (istore->dir_sep == '.') {
-				camel_imapx_server_rename_folder (istore->server, path, nfull, ex);
-			}
-
 			camel_store_info_set_string((CamelStoreSummary *)istore->summary, si, CAMEL_STORE_INFO_PATH, npath);
 			camel_store_info_set_string((CamelStoreSummary *)istore->summary, si, CAMEL_IMAPX_STORE_INFO_FULL_NAME, nfull);
 
@@ -671,6 +724,7 @@ static void
 imapx_rename_folder (CamelStore *store, const gchar *old, const gchar *new, CamelException *ex)
 {
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 	gchar *oldpath, *newpath, *storage_path;
 
 	if (CAMEL_OFFLINE_STORE (store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
@@ -682,8 +736,11 @@ imapx_rename_folder (CamelStore *store, const gchar *old, const gchar *new, Came
 	if (istore->rec_options & IMAPX_SUBSCRIPTIONS)
 		imapx_unsubscribe_folder (store, old, FALSE, ex);
 
-	if (istore->server && camel_imapx_server_connect (istore->server, TRUE, ex))
-		camel_imapx_server_rename_folder (istore->server, old, new, ex);
+	server = camel_imapx_store_get_server(istore, ex);
+	if (server) {
+		camel_imapx_server_rename_folder (server, old, new, ex);
+		camel_object_unref(server);
+	}
 
 	if (camel_exception_is_set (ex)) {
 		imapx_subscribe_folder (store, old, FALSE, ex);
@@ -714,10 +771,10 @@ imapx_rename_folder (CamelStore *store, const gchar *old, const gchar *new, Came
 static CamelFolderInfo *
 imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *folder_name, CamelException *ex)
 {
-	const gchar *c;
 	CamelStoreInfo *si;
 	CamelIMAPXStoreNamespace *ns;
 	CamelIMAPXStore *istore = (CamelIMAPXStore *) store;
+	CamelIMAPXServer *server;
 	gchar *real_name, *full_name, *parent_real;
 	CamelFolderInfo *fi = NULL;
 	gchar dir_sep;
@@ -728,7 +785,8 @@ imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *f
 		return NULL;
 	}
 
-	if (!(istore->server && camel_imapx_server_connect (istore->server, TRUE, ex)))
+	server = camel_imapx_store_get_server(istore, ex);
+	if (!server)
 		return NULL;
 
 	if (!parent_name)
@@ -740,14 +798,11 @@ imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *f
 	else
 		dir_sep = '/';
 
-	c = folder_name;
-	while (*c && *c != dir_sep && !strchr ("#%*", *c))
-		c++;
-
-	if (*c != '\0') {
+	if (strchr(folder_name, dir_sep)) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID_PATH,
 				      _("The folder name \"%s\" is invalid because it contains the character \"%c\""),
-				      folder_name, *c);
+				      folder_name, dir_sep);
+		camel_object_unref(server);
 		return NULL;
 	}
 
@@ -755,6 +810,7 @@ imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *f
 	if (parent_real == NULL) {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_FOLDER_INVALID_STATE,
 				     _("Unknown parent folder: %s"), parent_name);
+		camel_object_unref(server);
 		return NULL;
 	}
 
@@ -762,6 +818,7 @@ imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *f
 	if (si && si->flags & CAMEL_STORE_INFO_FOLDER_NOINFERIORS) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_FOLDER_INVALID_STATE,
 				_("The parent folder is not allowed to contain subfolders"));
+		camel_object_unref(server);
 		return NULL;
 	}
 
@@ -772,7 +829,8 @@ imapx_create_folder (CamelStore *store, const gchar *parent_name, const gchar *f
 	full_name = imapx_concat (istore, parent_real, real_name);
 	g_free(real_name);
 
-	camel_imapx_server_create_folder (istore->server, full_name, ex);
+	camel_imapx_server_create_folder (server, full_name, ex);
+	camel_object_unref(server);
 
 	if (!camel_exception_is_set (ex)) {
 		CamelIMAPXStoreInfo *si;
@@ -897,7 +955,7 @@ get_folder_info_offline (CamelStore *store, const gchar *top,
 }
 
 static void
-add_folders_to_summary (CamelIMAPXStore *istore, GPtrArray *folders, GHashTable *table, gboolean subcribed)
+add_folders_to_summary (CamelIMAPXStore *istore, CamelIMAPXServer *server, GPtrArray *folders, GHashTable *table, gboolean subscribed)
 {
 	gint i = 0;
 
@@ -905,18 +963,30 @@ add_folders_to_summary (CamelIMAPXStore *istore, GPtrArray *folders, GHashTable
 		struct _list_info *li = folders->pdata[i];
 		CamelIMAPXStoreInfo *si;
 		guint32 new_flags;
-		CamelFolderInfo *fi, *hfi;
+		CamelFolderInfo *fi, *sfi;
 		gchar *path;
 		CamelURL *url;
 
-		si = camel_imapx_store_summary_add_from_full (istore->summary, li->name, li->separator);
-		if (!si)
+		if (subscribed) {
+			path = camel_imapx_store_summary_path_to_full (istore->summary, li->name, li->separator);
+			sfi = g_hash_table_lookup (table, path);
+			if (sfi)
+				sfi->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
+
+			g_free(path);
 			continue;
+		}
+
+		si = camel_imapx_store_summary_add_from_full (istore->summary, li->name, li->separator);
+		if (!si) {
+			camel_object_unref(server);
+			continue;
+		}
 
 		new_flags = (si->info.flags & (CAMEL_STORE_INFO_FOLDER_SUBSCRIBED | CAMEL_STORE_INFO_FOLDER_CHECK_FOR_NEW)) |
 						(li->flags & ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED);
 
-		if (!(istore->server->cinfo->capa & IMAPX_CAPABILITY_NAMESPACE))
+		if (!istore->server->cinfo || !(istore->server->cinfo->capa & IMAPX_CAPABILITY_NAMESPACE))
 			istore->dir_sep = li->separator;
 
 		if (si->info.flags != new_flags) {
@@ -932,15 +1002,6 @@ add_folders_to_summary (CamelIMAPXStore *istore, GPtrArray *folders, GHashTable
 		} else
 			fi->name = g_strdup(camel_store_info_name(istore->summary, si));
 
-		hfi = g_hash_table_lookup (table, fi->full_name);
-		if (hfi) {
-			if (subcribed)
-				hfi->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
-
-			camel_folder_info_free (fi);
-			continue;
-		}
-
 		/* HACK: some servers report noinferiors for all folders (uw-imapd)
 		   We just translate this into nochildren, and let the imap layer enforce
 		   it.  See create folder */
@@ -948,9 +1009,6 @@ add_folders_to_summary (CamelIMAPXStore *istore, GPtrArray *folders, GHashTable
 			li->flags = (li->flags & ~CAMEL_FOLDER_NOINFERIORS) | CAMEL_FOLDER_NOCHILDREN;
 		fi->flags = li->flags;
 
-		if (subcribed)
-			fi->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
-
 		url = camel_url_new (istore->base_url, NULL);
 		path = alloca(strlen(fi->full_name)+2);
 		sprintf(path, "/%s", fi->full_name);
@@ -982,15 +1040,16 @@ imapx_get_folders_free(gpointer k, gpointer v, gpointer d)
 }
 
 static void
-fetch_folders_for_pattern (CamelIMAPXStore *istore, const gchar *pattern, guint32 flags, GHashTable *table, CamelException *ex)
+fetch_folders_for_pattern (CamelIMAPXStore *istore, CamelIMAPXServer *server, const gchar *pattern, guint32 flags,
+			   const gchar *ext, GHashTable *table, CamelException *ex)
 {
 	GPtrArray *folders = NULL;
 
-	folders = camel_imapx_server_list (istore->server, pattern, flags, ex);
+	folders = camel_imapx_server_list (server, pattern, flags, ext, ex);
 	if (camel_exception_is_set (ex))
 		return;
 
-	add_folders_to_summary (istore, folders, table, (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED));
+	add_folders_to_summary (istore, server, folders, table, (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED));
 
 	g_ptr_array_foreach (folders, free_list, folders);
 	g_ptr_array_free (folders, TRUE);
@@ -1017,9 +1076,14 @@ get_namespaces (CamelIMAPXStore *istore)
 static GHashTable *
 fetch_folders_for_namespaces (CamelIMAPXStore *istore, const gchar *pattern, gboolean sync, CamelException *ex)
 {
+	CamelIMAPXServer *server;
 	GHashTable *folders = NULL;
 	GSList *namespaces = NULL, *l;
 
+	server = camel_imapx_store_get_server(istore, ex);
+	if (!server)
+		return NULL;
+
 	folders = g_hash_table_new (folder_hash, folder_eq);
 	namespaces = get_namespaces (istore);
 
@@ -1030,6 +1094,7 @@ fetch_folders_for_namespaces (CamelIMAPXStore *istore, const gchar *pattern, gbo
 		while (ns) {
 			guint32 flags = 0;
 			gchar *pat = NULL;
+			const gchar *list_ext = NULL;
 
 			if (!pattern) {
 				if (!*ns->path)
@@ -1042,32 +1107,39 @@ fetch_folders_for_namespaces (CamelIMAPXStore *istore, const gchar *pattern, gbo
 			if (sync)
 				flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST;
 
+			if (server->cinfo->capa & IMAPX_CAPABILITY_LIST_EXTENDED)
+				list_ext = "RETURN (SUBSCRIBED)";
+
 			flags |= CAMEL_STORE_FOLDER_INFO_RECURSIVE;
-			fetch_folders_for_pattern (istore, pat, flags, folders, ex);
+			fetch_folders_for_pattern (istore, server, pat, flags, list_ext, folders, ex);
 			if (camel_exception_is_set (ex)) {
 				g_free (pat);
 				goto exception;
 			}
-
-			flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
-			fetch_folders_for_pattern (istore, pat, flags, folders, ex);
-			if (camel_exception_is_set (ex)) {
-				g_free (pat);
-				goto exception;
+			if (!list_ext) {
+				/* If the server doesn't support LIST-EXTENDED then we have to
+				   issue LSUB to list the subscribed folders separately */
+				flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
+				fetch_folders_for_pattern (istore, server, pat, flags, NULL, folders, ex);
+				if (camel_exception_is_set (ex)) {
+					g_free (pat);
+					goto exception;
+				}
 			}
-
 			g_free (pat);
 
 			if (pattern)
-				return folders;
+				goto out;
 
 			ns = ns->next;
 		}
 	}
-
+ out:
+	camel_object_unref(server);
 	return folders;
 
 exception:
+	camel_object_unref(server);
 	g_hash_table_destroy (folders);
 	return NULL;
 }
