@@ -37,8 +37,8 @@
 #include "camel-imapx-stream.h"
 #include "camel-imapx-exception.h"
 
-#define t(x) 
-#define io(x) x
+#define t(x) camel_imapx_debug(token, x)
+#define io(x) camel_imapx_debug(io, x)
 
 static CamelObjectClass *parent_class = NULL;
 
@@ -69,7 +69,7 @@ stream_fill(CamelIMAPXStream *is)
 		}
 	}
 
-	printf("camel_imapx_read: -1\n");
+	io(printf("camel_imapx_read: -1\n"));
 
 	return -1;
 }
@@ -200,7 +200,7 @@ camel_imapx_stream_get_type (void)
  * Returns a NULL stream.  A null stream is always at eof, and
  * always returns success for all reads and writes.
  *
- * Return value: the stream
+ * Returns: the stream
  **/
 CamelStream *
 camel_imapx_stream_new(CamelStream *source)
@@ -235,8 +235,8 @@ skip_ws(CamelIMAPXStream *is, guchar *pp, guchar *pe)
 	do {
 		while (p >= e ) {
 			is->ptr = p;
-			if (stream_fill(is) == IMAP_TOK_ERROR)
-				return IMAP_TOK_ERROR;
+			if (stream_fill(is) == IMAPX_TOK_ERROR)
+				return IMAPX_TOK_ERROR;
 			p = is->ptr;
 			e = is->end;
 		}
@@ -259,18 +259,18 @@ camel_imapx_stream_atom(CamelIMAPXStream *is, guchar **data, guint *lenp, CamelE
 
 	/* this is only 'approximate' atom */
 	switch (camel_imapx_stream_token(is, data, lenp, ex)) {
-	case IMAP_TOK_TOKEN:
+	case IMAPX_TOK_TOKEN:
 		p = *data;
 		while ((c = *p))
 			*p++ = toupper(c);
-	case IMAP_TOK_INT:
+	case IMAPX_TOK_INT:
 		return 0;
-	case IMAP_TOK_ERROR:
-		return IMAP_TOK_ERROR;
+	case IMAPX_TOK_ERROR:
+		return IMAPX_TOK_ERROR;
 	default:
 		camel_exception_set (ex, 1, "expecting atom");
-		printf("expecting atom!\n");
-		return IMAP_TOK_PROTOCOL;
+		io(printf("expecting atom!\n"));
+		return IMAPX_TOK_PROTOCOL;
 	}
 }
 
@@ -283,16 +283,16 @@ camel_imapx_stream_astring(CamelIMAPXStream *is, guchar **data, CamelException *
 	gint ret;
 
 	switch (camel_imapx_stream_token(is, data, &len, ex)) {
-	case IMAP_TOK_TOKEN:
-	case IMAP_TOK_INT:
-	case IMAP_TOK_STRING:
+	case IMAPX_TOK_TOKEN:
+	case IMAPX_TOK_INT:
+	case IMAPX_TOK_STRING:
 		return 0;
-	case IMAP_TOK_LITERAL:
+	case IMAPX_TOK_LITERAL:
 		/* FIXME: just grow buffer */
 		if (len >= CAMEL_IMAPX_STREAM_TOKEN) {
 			camel_exception_set (ex, 1, "astring: literal too long");
-			printf("astring too long\n");
-			return IMAP_TOK_PROTOCOL;
+			io(printf("astring too long\n"));
+			return IMAPX_TOK_PROTOCOL;
 		}
 		p = is->tokenptr;
 		camel_imapx_stream_set_literal(is, len);
@@ -303,15 +303,16 @@ camel_imapx_stream_astring(CamelIMAPXStream *is, guchar **data, CamelException *
 			memcpy(p, start, inlen);
 			p += inlen;
 		} while (ret > 0);
+		*p = 0;
 		*data = is->tokenptr;
 		return 0;
-	case IMAP_TOK_ERROR:
+	case IMAPX_TOK_ERROR:
 		/* wont get unless no exception hanlder*/
-		return IMAP_TOK_ERROR;
+		return IMAPX_TOK_ERROR;
 	default:
 		camel_exception_set (ex, 1, "expecting astring");
-		printf("expecting astring!\n");
-		return IMAP_TOK_PROTOCOL;
+		io(printf("expecting astring!\n"));
+		return IMAPX_TOK_PROTOCOL;
 	}
 }
 
@@ -324,13 +325,13 @@ camel_imapx_stream_nstring(CamelIMAPXStream *is, guchar **data, CamelException *
 	gint ret;
 
 	switch (camel_imapx_stream_token(is, data, &len, ex)) {
-	case IMAP_TOK_STRING:
+	case IMAPX_TOK_STRING:
 		return 0;
-	case IMAP_TOK_LITERAL:
+	case IMAPX_TOK_LITERAL:
 		/* FIXME: just grow buffer */
 		if (len >= CAMEL_IMAPX_STREAM_TOKEN) {
 			camel_exception_set (ex, 1, "nstring: literal too long");
-			return IMAP_TOK_PROTOCOL;
+			return IMAPX_TOK_PROTOCOL;
 		}
 		p = is->tokenptr;
 		camel_imapx_stream_set_literal(is, len);
@@ -341,9 +342,10 @@ camel_imapx_stream_nstring(CamelIMAPXStream *is, guchar **data, CamelException *
 			memcpy(p, start, inlen);
 			p += inlen;
 		} while (ret > 0);
+		*p = 0;
 		*data = is->tokenptr;
 		return 0;
-	case IMAP_TOK_TOKEN:
+	case IMAPX_TOK_TOKEN:
 		p = *data;
 		if (toupper(p[0]) == 'N' && toupper(p[1]) == 'I' && toupper(p[2]) == 'L' && p[3] == 0) {
 			*data = NULL;
@@ -351,10 +353,10 @@ camel_imapx_stream_nstring(CamelIMAPXStream *is, guchar **data, CamelException *
 		}
 	default:
 		camel_exception_set (ex, 1, "expecting nstring");
-		return IMAP_TOK_PROTOCOL;
-	case IMAP_TOK_ERROR:
+		return IMAPX_TOK_PROTOCOL;
+	case IMAPX_TOK_ERROR:
 		/* we'll never get this unless there are no exception  handlers anyway */
-		return IMAP_TOK_ERROR;
+		return IMAPX_TOK_ERROR;
 
 	}
 }
@@ -372,11 +374,11 @@ camel_imapx_stream_nstring_stream(CamelIMAPXStream *is, CamelStream **stream, Ca
 	*stream = NULL;
 
 	switch (camel_imapx_stream_token(is, &token, &len, ex)) {
-		case IMAP_TOK_STRING:
+		case IMAPX_TOK_STRING:
 			mem = camel_stream_mem_new_with_buffer((gchar *)token, len);
 			*stream = mem;
 			break;
-		case IMAP_TOK_LITERAL:
+		case IMAPX_TOK_LITERAL:
 			/* if len is big, we could automatically use a file backing */
 			camel_imapx_stream_set_literal(is, len);
 			mem = camel_stream_mem_new();
@@ -389,7 +391,7 @@ camel_imapx_stream_nstring_stream(CamelIMAPXStream *is, CamelStream **stream, Ca
 			camel_stream_reset(mem);
 			*stream = mem;
 			break;
-		case IMAP_TOK_TOKEN:
+		case IMAPX_TOK_TOKEN:
 			if (toupper(token[0]) == 'N' && toupper(token[1]) == 'I' && toupper(token[2]) == 'L' && token[3] == 0) {
 				*stream = NULL;
 				break;
@@ -402,18 +404,18 @@ camel_imapx_stream_nstring_stream(CamelIMAPXStream *is, CamelStream **stream, Ca
 	return ret;
 }
 
-guint32
+guint64
 camel_imapx_stream_number(CamelIMAPXStream *is, CamelException *ex)
 {
 	guchar *token;
 	guint len;
 
-	if (camel_imapx_stream_token(is, &token, &len, ex) != IMAP_TOK_INT) {
+	if (camel_imapx_stream_token(is, &token, &len, ex) != IMAPX_TOK_INT) {
 		camel_exception_set (ex, 1, "expecting number");
 		return 0;
 	}
 
-	return strtoul((gchar *)token, 0, 10);
+	return strtoull((gchar *)token, 0, 10);
 }
 
 gint
@@ -426,9 +428,9 @@ camel_imapx_stream_text(CamelIMAPXStream *is, guchar **text, CamelException *ex)
 
 	while (is->unget > 0) {
 		switch (is->unget_tok) {
-			case IMAP_TOK_TOKEN:
-			case IMAP_TOK_STRING:
-			case IMAP_TOK_INT:
+			case IMAPX_TOK_TOKEN:
+			case IMAPX_TOK_STRING:
+			case IMAPX_TOK_INT:
 				g_byte_array_append(build, (guint8 *) is->unget_token, is->unget_len);
 				g_byte_array_append(build, (guint8 *) " ", 1);
 			default: /* invalid, but we'll ignore */
@@ -484,7 +486,7 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 	do {
 		while (p >= e ) {
 			is->ptr = p;
-			if (stream_fill(is) == IMAP_TOK_ERROR)
+			if (stream_fill(is) == IMAPX_TOK_ERROR)
 				goto io_error;
 			p = is->ptr;
 			e = is->end;
@@ -514,25 +516,26 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 								is->ptr = p;
 								is->literal = literal;
 								t(printf("token LITERAL %d\n", literal));
-								return IMAP_TOK_LITERAL;
+								return IMAPX_TOK_LITERAL;
 							}
 						}
 						is->ptr = p;
-						if (stream_fill(is) == IMAP_TOK_ERROR)
+						if (stream_fill(is) == IMAPX_TOK_ERROR)
 							goto io_error;
 						p = is->ptr;
 						e = is->end;
 					}
 				} else {
-					if (isdigit(c))
-						printf("Protocol error: literal too big\n");
-					else
-						printf("Protocol error: literal contains invalid gchar %02x '%c'\n", c, isprint(c)?c:c);
+					if (isdigit(c)) {
+						io(printf("Protocol error: literal too big\n"));
+					} else {
+						io(printf("Protocol error: literal contains invalid gchar %02x '%c'\n", c, isprint(c)?c:c));
+					}
 					goto protocol_error;
 				}
 			}
 			is->ptr = p;
-			if (stream_fill(is) == IMAP_TOK_ERROR)
+			if (stream_fill(is) == IMAPX_TOK_ERROR)
 				goto io_error;
 			p = is->ptr;
 			e = is->end;
@@ -546,7 +549,7 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 				if (c == '\\') {
 					while (p >= e) {
 						is->ptr = p;
-						if (stream_fill(is) == IMAP_TOK_ERROR)
+						if (stream_fill(is) == IMAPX_TOK_ERROR)
 							goto io_error;
 						p = is->ptr;
 						e = is->end;
@@ -558,21 +561,24 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 					*data = is->tokenbuf;
 					*len = o - is->tokenbuf;
 					t(printf("token STRING '%s'\n", is->tokenbuf));
-					return IMAP_TOK_STRING;
+					return IMAPX_TOK_STRING;
 				}
 
 				if (c == '\n' || c == '\r' || o>=oe) {
-					if (o >= oe)
-						printf("Protocol error: string too long\n");
-					else
-						printf("Protocol error: truncated string\n");
+					if (o >= oe) {
+						io(printf("Protocol error: string too long\n"));
+
+					} else {
+						io(printf("Protocol error: truncated string\n"));
+					}
+
 					goto protocol_error;
 				} else {
 					*o++ = c;
 				}
 			}
 			is->ptr = p;
-			if (stream_fill(is) == IMAP_TOK_ERROR)
+			if (stream_fill(is) == IMAPX_TOK_ERROR)
 				goto io_error;
 			p = is->ptr;
 			e = is->end;
@@ -595,17 +601,17 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 					*data = is->tokenbuf;
 					*len = o - is->tokenbuf;
 					t(printf("token TOKEN '%s'\n", is->tokenbuf));
-					return digits?IMAP_TOK_INT:IMAP_TOK_TOKEN;
+					return digits?IMAPX_TOK_INT:IMAPX_TOK_TOKEN;
 				} else if (o < oe) {
 					digits &= isdigit(c);
 					*o++ = c;
 				} else {
-					printf("Protocol error: token too long\n");
+					io(printf("Protocol error: token too long\n"));
 					goto protocol_error;
 				}
 			}
 			is->ptr = p;
-			if (stream_fill(is) == IMAP_TOK_ERROR)
+			if (stream_fill(is) == IMAPX_TOK_ERROR)
 				goto io_error;
 			p = is->ptr;
 			e = is->end;
@@ -614,13 +620,12 @@ camel_imapx_stream_token(CamelIMAPXStream *is, guchar **data, guint *len, CamelE
 
 	/* Had an i/o erorr */
 io_error:
-	printf("Got io error\n");
 	camel_exception_set (ex, 1, "io error");
-	return IMAP_TOK_ERROR;
+	return IMAPX_TOK_ERROR;
 
 	/* Protocol error, skip until next lf? */
 protocol_error:
-	printf("Got protocol error\n");
+	io(printf("Got protocol error\n"));
 
 	if (c == '\n')
 		is->ptr = p-1;
@@ -628,7 +633,7 @@ protocol_error:
 		is->ptr = p;
 
 	camel_exception_set (ex, 1, "protocol error");
-	return IMAP_TOK_PROTOCOL;
+	return IMAPX_TOK_PROTOCOL;
 }
 
 void
@@ -710,10 +715,10 @@ camel_imapx_stream_skip(CamelIMAPXStream *is, CamelException *ex)
 
 	do {
 		tok = camel_imapx_stream_token(is, &token, &len, ex);
-		if (tok == IMAP_TOK_LITERAL) {
+		if (tok == IMAPX_TOK_LITERAL) {
 			camel_imapx_stream_set_literal(is, len);
 			while ((tok = camel_imapx_stream_getl(is, &token, &len)) > 0) {
-				printf("Skip literal data '%.*s'\n", (gint)len, token);
+				io(printf("Skip literal data '%.*s'\n", (gint)len, token));
 			}
 		}
 	} while (tok != '\n' && tok >= 0);
