@@ -4,7 +4,7 @@
  *  JP Rosevear <jpr@ximian.com>
  *  Rodrigo Moya <rodrigo@ximian.com>
  *
- * Copyright 2003, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -24,25 +24,24 @@
 #ifndef E_GW_MESSAGE_H
 #define E_GW_MESSAGE_H
 
-#include <libsoup/soup-soap-message.h>
+#include "soup-soap-message.h"
 
 G_BEGIN_DECLS
 
-SoupSoapMessage *e_gw_message_new_with_header (const char *uri, const char *session_id, const char *method_name);
-void             e_gw_message_write_string_parameter (SoupSoapMessage *msg, const char *name,
-						      const char *prefix, const char *value);
+SoupSoapMessage *e_gw_message_new_with_header (const gchar *uri, const gchar *session_id, const gchar *method_name);
+void             e_gw_message_write_string_parameter (SoupSoapMessage *msg, const gchar *name,
+						      const gchar *prefix, const gchar *value);
 void             e_gw_message_write_string_parameter_with_attribute (SoupSoapMessage *msg,
-								     const char *name,
-								     const char *prefix,
-								     const char *value,
-								     const char *attrubute_name,
-								     const char *attribute_value);
+								     const gchar *name,
+								     const gchar *prefix,
+								     const gchar *value,
+								     const gchar *attrubute_name,
+								     const gchar *attribute_value);
 void             e_gw_message_write_base64_parameter (SoupSoapMessage *msg,
-						      const char *name,
-						      const char *prefix,
-						      const char *value);
-void e_gw_message_write_int_parameter (SoupSoapMessage *msg, const char *name, const char *prefix, long value);
-
+						      const gchar *name,
+						      const gchar *prefix,
+						      const gchar *value);
+void e_gw_message_write_int_parameter (SoupSoapMessage *msg, const gchar *name, const gchar *prefix, glong value);
 
 void             e_gw_message_write_footer (SoupSoapMessage *msg);
 
